@@ -135,8 +135,48 @@ double quiskFilt12_19Coefs[64] = { 0.000043810351462319, 0.000138863869398690, 0
 -0.001353635480056038, -0.000514727559529336, 0.000047730531591317, 0.000206835545025070, 0.000138863869398690,
  0.000043810351462319} ;
 
+// Sample 185185 Hz, pass 20000, stop 24000, ripple 0.1 dB, atten 100 dB.  For SDR-IQ.
+double quiskFilt185D3Coefs[188] = { 0.000008153800001840, -0.000001771417630395, -0.000037253333929034, -0.000119009795238060,
+-0.000255018503860098, -0.000431457630502916, -0.000606779374823655, -0.000718366697089728, -0.000703620301380014,
+-0.000529751805487936, -0.000219462957628643, 0.000142545317473537, 0.000431747689511389, 0.000531458261578183,
+ 0.000388343045150861, 0.000049369127393032, -0.000342917144392365, -0.000603313895145129, -0.000587692675369399,
+-0.000270442421243832, 0.000225386999468089, 0.000669074815263746, 0.000825032169620294, 0.000573830722863008,
+-0.000009077307935200, -0.000664918089414559, -0.001061106586632969, -0.000955502500127749, -0.000336438190374833,
+ 0.000539349074607305, 0.001245645977048461, 0.001389173752996503, 0.000822043470106957, -0.000247598052622219,
+-0.001319476735963911, -0.001828796700280690, -0.001437569856610004, -0.000242431773066792, 0.001222656916942065,
+ 0.002216144517102359, 0.002157389501918925, 0.000954312268698896, -0.000889647952809809, -0.002472890164473277,
+-0.002928202444412127, -0.001887404641539060, 0.000266028947341680, 0.002515528194768854, 0.003680340277064590,
+ 0.003024505869869945, 0.000697099931502566, -0.002249597199494156, -0.004320335692842188, -0.004323014468691384,
+-0.002034738390180464, 0.001575270318365026, 0.004732326142178709, 0.005712473175796522, 0.003763483203528208,
+-0.000391719810437692, -0.004781111888508037, -0.007096880559266867, -0.005884712017661407, -0.001407862533738378,
+ 0.004306693842081116, 0.008352211939490001, 0.008388529075785354, 0.003946736249321500, -0.003112792599933821,
+-0.009323923519118172, -0.011269282117577429, -0.007398426385575320, 0.000928531365753789, 0.009809484942446507,
+ 0.014553037120437585, 0.012062615692744548, 0.002683413619215453, -0.009516487432546697, -0.018375440190605826,
+-0.018584023004946444, -0.008607549657362717, 0.007911844367040830, 0.023198314076417474, 0.028659214411537771,
+ 0.019167047651360933, -0.003633593297082508, -0.030707268487267729, -0.048352925046987114, -0.043463395046782413,
+-0.009280832167164070, 0.050801866891763532, 0.123196454160356600, 0.188154012695948810, 0.226499569996940320,
+ 0.226499569996940320, 0.188154012695948810, 0.123196454160356600, 0.050801866891763532, -0.009280832167164070,
+-0.043463395046782413, -0.048352925046987114, -0.030707268487267729, -0.003633593297082508, 0.019167047651360933,
+ 0.028659214411537771, 0.023198314076417474, 0.007911844367040830, -0.008607549657362717, -0.018584023004946444,
+-0.018375440190605826, -0.009516487432546697, 0.002683413619215453, 0.012062615692744548, 0.014553037120437585,
+ 0.009809484942446507, 0.000928531365753789, -0.007398426385575320, -0.011269282117577429, -0.009323923519118172,
+-0.003112792599933821, 0.003946736249321500, 0.008388529075785354, 0.008352211939490001, 0.004306693842081116,
+-0.001407862533738378, -0.005884712017661407, -0.007096880559266867, -0.004781111888508037, -0.000391719810437692,
+ 0.003763483203528208, 0.005712473175796522, 0.004732326142178709, 0.001575270318365026, -0.002034738390180464,
+-0.004323014468691384, -0.004320335692842188, -0.002249597199494156, 0.000697099931502566, 0.003024505869869945,
+ 0.003680340277064590, 0.002515528194768854, 0.000266028947341680, -0.001887404641539060, -0.002928202444412127,
+-0.002472890164473277, -0.000889647952809809, 0.000954312268698896, 0.002157389501918925, 0.002216144517102359,
+ 0.001222656916942065, -0.000242431773066792, -0.001437569856610004, -0.001828796700280690, -0.001319476735963911,
+-0.000247598052622219, 0.000822043470106957, 0.001389173752996503, 0.001245645977048461, 0.000539349074607305,
+-0.000336438190374833, -0.000955502500127749, -0.001061106586632969, -0.000664918089414559, -0.000009077307935200,
+ 0.000573830722863008, 0.000825032169620294, 0.000669074815263746, 0.000225386999468089, -0.000270442421243832,
+-0.000587692675369399, -0.000603313895145129, -0.000342917144392365, 0.000049369127393032, 0.000388343045150861,
+ 0.000531458261578183, 0.000431747689511389, 0.000142545317473537, -0.000219462957628643, -0.000529751805487936,
+-0.000703620301380014, -0.000718366697089728, -0.000606779374823655, -0.000431457630502916, -0.000255018503860098,
+-0.000119009795238060, -0.000037253333929034, -0.000001771417630395, 0.000008153800001840 };
+
 // Sample 185185 Hz, pass 15000, stop 23900, ripple 0.1 dB, atten 100 dB.  For SDR-IQ.
-double quiskFilt185D3Coefs[88] = { -0.000026016801458962, -0.000079343977811083, -0.000167897725115826, -0.000272158478205181,
+double quiskFilt185D3XCoefs[88] = { -0.000026016801458962, -0.000079343977811083, -0.000167897725115826, -0.000272158478205181,
 -0.000343785933253942, -0.000310796788289393, -0.000102311891399797, 0.000311300138822939, 0.000877228005105512, 0.001440583394256035,
  0.001767836749778265, 0.001621580974541500, 0.000871040137123456, -0.000402149294308734, -0.001857385353819294, -0.002952994474321905,
 -0.003118971956742465, -0.002002468636632821, 0.000304795748571584, 0.003168465665729574, 0.005527734084410955, 0.006236194024480606,
@@ -219,6 +259,36 @@ double quiskFilt185D7Coefs[325] = { 0.000011585872492535, 0.000021202775655724,
  0.000292202414812531, 0.000259582942086064, 0.000218342986026828, 0.000174225065604974, 0.000131718743859808,
  0.000093940890103130, 0.000062668164659740, 0.000038515581433427, 0.000021202775655724, 0.000011585872492535} ;
 
+// Sample 133333 Hz, pass 20000, stop 24000, ripple 0.1 dB, atten 100 dB.  For SDR-IQ.
+double quiskFilt133D2Coefs[136] = { 0.000017194140195307, 0.000013031580406032, -0.000070982819622986, -0.000297799318127961,
+-0.000645057684247744, -0.000951723373793975, -0.000976667009837673, -0.000579840699091521, 0.000098129751533427,
+ 0.000644977424009104, 0.000648591932388761, 0.000063466245825653, -0.000655952785922865, -0.000858530950797784,
+-0.000263313568128542, 0.000697280609267464, 0.001152025473909408, 0.000556416972642962, -0.000702600426682260,
+-0.001503408593721275, -0.000962293487226091, 0.000635424413378249, 0.001893865760533597, 0.001494654948692980,
+-0.000464212878209573, -0.002304129661798076, -0.002165029121341371, 0.000156986911460916, 0.002712310672598236,
+ 0.002984071948396753, 0.000321449210044334, -0.003091821762536665, -0.003961473137247651, -0.001010870707262950,
+ 0.003410242877909513, 0.005106330989341096, 0.001957278141537391, -0.003628441800145526, -0.006428886895772534,
+-0.003216116999687284, 0.003699894436571663, 0.007945926308831793, 0.004862613142073883, -0.003562107867854992,
+-0.009680253224586733, -0.006996529395398682, 0.003139846233471389, 0.011684868441375082, 0.009783362061267441,
+-0.002313232717655680, -0.014049355073607583, -0.013495163730537300, 0.000895100102567855, 0.016959635420547809,
+ 0.018648538187471329, 0.001461901498462892, -0.020821848411902603, -0.026360133080398199, -0.005525410959722330,
+ 0.026648719554864163, 0.039549486288596822, 0.013454287175328376, -0.037723817929648518, -0.068973339495709857,
+-0.034792487725714472, 0.073207163331834649, 0.211614628197181350, 0.308128392192117740, 0.308128392192117740,
+ 0.211614628197181350, 0.073207163331834649, -0.034792487725714472, -0.068973339495709857, -0.037723817929648518,
+ 0.013454287175328376, 0.039549486288596822, 0.026648719554864163, -0.005525410959722330, -0.026360133080398199,
+-0.020821848411902603, 0.001461901498462892, 0.018648538187471329, 0.016959635420547809, 0.000895100102567855,
+-0.013495163730537300, -0.014049355073607583, -0.002313232717655680, 0.009783362061267441, 0.011684868441375082,
+ 0.003139846233471389, -0.006996529395398682, -0.009680253224586733, -0.003562107867854992, 0.004862613142073883,
+ 0.007945926308831793, 0.003699894436571663, -0.003216116999687284, -0.006428886895772534, -0.003628441800145526,
+ 0.001957278141537391, 0.005106330989341096, 0.003410242877909513, -0.001010870707262950, -0.003961473137247651,
+-0.003091821762536665, 0.000321449210044334, 0.002984071948396753, 0.002712310672598236, 0.000156986911460916,
+-0.002165029121341371, -0.002304129661798076, -0.000464212878209573, 0.001494654948692980, 0.001893865760533597,
+ 0.000635424413378249, -0.000962293487226091, -0.001503408593721275, -0.000702600426682260, 0.000556416972642962,
+ 0.001152025473909408, 0.000697280609267464, -0.000263313568128542, -0.000858530950797784, -0.000655952785922865,
+ 0.000063466245825653, 0.000648591932388761, 0.000644977424009104, 0.000098129751533427, -0.000579840699091521,
+-0.000976667009837673, -0.000951723373793975, -0.000645057684247744, -0.000297799318127961, -0.000070982819622986,
+ 0.000013031580406032, 0.000017194140195307 } ;
+
 // Sample 133333 Hz, pass 10000, stop 12000, ripple 0.5 dB, atten 100 dB.  For SDR-IQ.
 double quiskFilt133D5Coefs[235] = { 0.000017189993342429, 0.000044738485582654, 0.000095017992345093, 0.000171520768649681,
  0.000274754514100238, 0.000398861594001340, 0.000529984999270100, 0.000646117397525726, 0.000718766415753168,
@@ -269,6 +339,31 @@ double quiskFilt133D5Coefs[235] = { 0.000017189993342429, 0.000044738485582654,
  0.000398861594001340, 0.000274754514100238, 0.000171520768649681, 0.000095017992345093, 0.000044738485582654,
  0.000017189993342429} ;
 
+// Sample 111111 Hz, pass 20000, stop 24000, ripple 0.1 dB, atten 100 dB.  For SDR-IQ.
+double quiskFilt111D2Coefs[114] = { 0.000039619752517087, 0.000089439819783633, 0.000017353012666121, -0.000334808345968833,
+-0.000892257134326630, -0.001221700854092078, -0.000859742027523152, 0.000086110163390211, 0.000794431841612731,
+ 0.000492910288706401, -0.000542730604541516, -0.001057738392194920, -0.000232619264909279, 0.001101735902638522,
+ 0.001208303693873524, -0.000351788978766190, -0.001781186751638964, -0.001038581835235810, 0.001330430232082531,
+ 0.002355496074120870, 0.000292615997120782, -0.002623102550864884, -0.002462643018753817, 0.001194053806308097,
+ 0.003912675164153385, 0.001670607202119238, -0.003361036335001390, -0.004638914091859385, 0.000363767953875138,
+ 0.005797757906125993, 0.004088942448683545, -0.003689094083671128, -0.007701448612726584, -0.001601464053307583,
+ 0.007864313939600763, 0.007963248868264130, -0.003156323310881499, -0.011852746523309575, -0.005390083465132761,
+ 0.009915212572859983, 0.014053676129843581, -0.000996935620086296, -0.017619302590712586, -0.012439281622203873,
+ 0.011722997082370391, 0.024364733312011930, 0.004596957308944789, -0.026911691600293927, -0.027288530345555617,
+ 0.013072844783675014, 0.047281998734662697, 0.021354076339639792, -0.051099079289920336, -0.080397920778604998,
+ 0.013794073914731197, 0.205298935938689170, 0.362799183591728360, 0.362799183591728360, 0.205298935938689170,
+ 0.013794073914731197, -0.080397920778604998, -0.051099079289920336, 0.021354076339639792, 0.047281998734662697,
+ 0.013072844783675014, -0.027288530345555617, -0.026911691600293927, 0.004596957308944789, 0.024364733312011930,
+ 0.011722997082370391, -0.012439281622203873, -0.017619302590712586, -0.000996935620086296, 0.014053676129843581,
+ 0.009915212572859983, -0.005390083465132761, -0.011852746523309575, -0.003156323310881499, 0.007963248868264130,
+ 0.007864313939600763, -0.001601464053307583, -0.007701448612726584, -0.003689094083671128, 0.004088942448683545,
+ 0.005797757906125993, 0.000363767953875138, -0.004638914091859385, -0.003361036335001390, 0.001670607202119238,
+ 0.003912675164153385, 0.001194053806308097, -0.002462643018753817, -0.002623102550864884, 0.000292615997120782,
+ 0.002355496074120870, 0.001330430232082531, -0.001038581835235810, -0.001781186751638964, -0.000351788978766190,
+ 0.001208303693873524, 0.001101735902638522, -0.000232619264909279, -0.001057738392194920, -0.000542730604541516,
+ 0.000492910288706401, 0.000794431841612731, 0.000086110163390211, -0.000859742027523152, -0.001221700854092078,
+-0.000892257134326630, -0.000334808345968833, 0.000017353012666121, 0.000089439819783633, 0.000039619752517087 } ;
+
 // Sample 111111 Hz, pass 10000, stop 12000, ripple 0.5 dB, atten 100 dB.  For SDR-IQ.
 double quiskFilt111D4Coefs[196] = { 0.000022860383861326, 0.000070265173417164, 0.000160689233204503, 0.000301317969124407,
  0.000487289901409396, 0.000694724116305488, 0.000878636067621920, 0.000977522977076171, 0.000925771316840867,
@@ -311,6 +406,18 @@ double quiskFilt111D4Coefs[196] = { 0.000022860383861326, 0.000070265173417164,
  0.000878636067621920, 0.000694724116305488, 0.000487289901409396, 0.000301317969124407, 0.000160689233204503,
  0.000070265173417164, 0.000022860383861326} ;
 
+// Sample 53333 Hz, pass 20000, stop 24000, ripple 0.1 dB, atten 100 dB.  For SDR-IQ.
+double quiskFilt53D1Coefs[55] = { 0.000318858391362187, 0.001662116369387873, -0.000065237353639775, -0.000854885424783294,
+ 0.001693126335254083, -0.002034310867663472, 0.001354648789538254, 0.000509693525155950, -0.003079059747940221, 0.005242349925004462,
+-0.005626507739484119, 0.003235398612833476, 0.001883583294529978, -0.008273775245721798, 0.013282431836060808, -0.013924391581141530,
+ 0.008176677795586052, 0.003763659697675038, -0.018814370186261472, 0.031357304759835808, -0.034684131608746831, 0.023184334016039702,
+ 0.005435239957731122, -0.048724194253317150, 0.099481724552805198, -0.147334801628740130, 0.181502639813268140, 0.806108236192275450,
+ 0.181502639813268140, -0.147334801628740130, 0.099481724552805198, -0.048724194253317150, 0.005435239957731122, 0.023184334016039702,
+-0.034684131608746831, 0.031357304759835808, -0.018814370186261472, 0.003763659697675038, 0.008176677795586052, -0.013924391581141530,
+ 0.013282431836060808, -0.008273775245721798, 0.001883583294529978, 0.003235398612833476, -0.005626507739484119, 0.005242349925004462,
+-0.003079059747940221, 0.000509693525155950, 0.001354648789538254, -0.002034310867663472, 0.001693126335254083, -0.000854885424783294,
+-0.000065237353639775, 0.001662116369387873, 0.000318858391362187 } ;
+
 // Sample 53333 Hz, pass 10000, stop 12000, ripple 0.5 dB, atten 100 dB.  For SDR-IQ.
 double quiskFilt53D2Coefs[93] = { 0.000107966318729964, 0.000421475598772498, 0.000731343669484184, 0.000328611865414609,
 -0.001457272471508304, -0.004143803290279123, -0.005736802939367581, -0.004303861070721504, -0.000415676176666607,
@@ -332,6 +439,7 @@ double quiskFilt53D2Coefs[93] = { 0.000107966318729964, 0.000421475598772498, 0.
 -0.000415676176666607, -0.004303861070721504, -0.005736802939367581, -0.004143803290279123, -0.001457272471508304,
  0.000328611865414609, 0.000731343669484184, 0.000421475598772498, 0.000107966318729964} ;
 
+
 // Sample 240 kHz, pass 15, stop 23.9, ripple 0. 1dB, atten 100 dB, taps 114.  For 240 to 48 decimation by 5.
 double quiskFilt240D5Coefs[114] = { -0.000017444714121896, -0.000043389176259008, -0.000086666475464372, -0.000143622066705595,
 -0.000204429258992282, -0.000250894192563019, -0.000258038648420713, -0.000198760816315186, -0.000051592624047688, 0.000190007232237523,
@@ -354,6 +462,58 @@ double quiskFilt240D5Coefs[114] = { -0.000017444714121896, -0.000043389176259008
 -0.000198760816315186, -0.000258038648420713, -0.000250894192563019, -0.000204429258992282, -0.000143622066705595, -0.000086666475464372,
 -0.000043389176259008, -0.000017444714121896} ;
 
+// Sample 240 kHz, pass 20, stop 24, ripple 0. 1dB, atten 100 dB, taps 114.  For 240 to 48 decimation by 5.
+double quiskFilt240D5CoefsSharp[246] = { 0.000011951828200011, 0.000019798433756403, 0.000028547330106604, 0.000030165284908057,
+ 0.000016460532579755, -0.000020835366942643, -0.000087256395370183, -0.000182447830402188, -0.000297836387286273,
+-0.000416082361724969, -0.000513090543707066, -0.000562800094080439, -0.000543922161049598, -0.000447038893351438,
+-0.000279964105369211, -0.000069269573936326, 0.000143339868281261, 0.000309776397278667, 0.000387771231401110,
+ 0.000353469185042608, 0.000210686954436390, -0.000006554284588476, -0.000240063519947365, -0.000421527417296624,
+-0.000491443283168306, -0.000417820101680067, -0.000208868052760534, 0.000085048027839757, 0.000382180878613336,
+ 0.000591123735768924, 0.000638042870263572, 0.000491558598565883, 0.000177179393286866, -0.000224481053594759,
+-0.000597014064504330, -0.000820930704466417, -0.000810918218693337, -0.000546326732285124, -0.000084459306793206,
+ 0.000449422013818846, 0.000894687281371102, 0.001102541594699144, 0.000984325470442889, 0.000545624937191001,
+-0.000106146183328305, -0.000785797405770491, -0.001281535037100789, -0.001419612701203994, -0.001123137180667268,
+-0.000445673862380164, 0.000433514280597531, 0.001254730807221768, 0.001752968220115270, 0.001741675133186359,
+ 0.001179202567033726, 0.000195102369455356, -0.000935783344044036, -0.001867876483977602, -0.002288593398642863,
+-0.002020698232986274, -0.001090456401574151, 0.000263178814654847, 0.001646402890369986, 0.002622726888175473,
+ 0.002848310252497599, 0.002189220340667481, 0.000781654013623377, -0.000988901141783250, -0.002589700588821625,
+-0.003498176390167329, -0.003369141152473258, -0.002159241772770695, -0.000165464996932323, 0.002041618007644499,
+ 0.003777187265991297, 0.004450866229775656, 0.003762315917274342, 0.001820394865830094, -0.000858234059046015,
+-0.003480363951041699, -0.005206132491721142, -0.005412440056656052, -0.003908911556192801, -0.001033963211572532,
+ 0.002409267811432101, 0.005369858454077349, 0.006862619655562839, 0.006286791984567192, 0.003649433286047820,
+-0.000385090824056697, -0.004649684536230074, -0.007801516508809942, -0.008732884415488085, -0.006943637236744675,
+-0.002754601930921507, 0.002718968772510816, 0.007846810206617289, 0.010951016745475875, 0.010832279872067337,
+ 0.007196213900006544, 0.000837720738654166, -0.006496855603590420, -0.012558347528192997, -0.015246550948573622,
+-0.013285617706403107, -0.006719315573973105, 0.002942907242266441, 0.013010190699738699, 0.020286552390091313,
+ 0.021982424443790855, 0.016621666248368951, 0.004683273039499340, -0.011231582005110220, -0.026802267461528154,
+-0.036907110368292514, -0.036858745295310878, -0.023657596515413496, 0.003060851507965577, 0.040649713296411087,
+ 0.083777373113400611, 0.125416065458074430, 0.158282028171104980, 0.176396323031566690, 0.176396323031566690,
+ 0.158282028171104980, 0.125416065458074430, 0.083777373113400611, 0.040649713296411087, 0.003060851507965577,
+-0.023657596515413496, -0.036858745295310878, -0.036907110368292514, -0.026802267461528154, -0.011231582005110220,
+ 0.004683273039499340, 0.016621666248368951, 0.021982424443790855, 0.020286552390091313, 0.013010190699738699,
+ 0.002942907242266441, -0.006719315573973105, -0.013285617706403107, -0.015246550948573622, -0.012558347528192997,
+-0.006496855603590420, 0.000837720738654166, 0.007196213900006544, 0.010832279872067337, 0.010951016745475875,
+ 0.007846810206617289, 0.002718968772510816, -0.002754601930921507, -0.006943637236744675, -0.008732884415488085,
+-0.007801516508809942, -0.004649684536230074, -0.000385090824056697, 0.003649433286047820, 0.006286791984567192,
+ 0.006862619655562839, 0.005369858454077349, 0.002409267811432101, -0.001033963211572532, -0.003908911556192801,
+-0.005412440056656052, -0.005206132491721142, -0.003480363951041699, -0.000858234059046015, 0.001820394865830094,
+ 0.003762315917274342, 0.004450866229775656, 0.003777187265991297, 0.002041618007644499, -0.000165464996932323,
+-0.002159241772770695, -0.003369141152473258, -0.003498176390167329, -0.002589700588821625, -0.000988901141783250,
+ 0.000781654013623377, 0.002189220340667481, 0.002848310252497599, 0.002622726888175473, 0.001646402890369986,
+ 0.000263178814654847, -0.001090456401574151, -0.002020698232986274, -0.002288593398642863, -0.001867876483977602,
+-0.000935783344044036, 0.000195102369455356, 0.001179202567033726, 0.001741675133186359, 0.001752968220115270,
+ 0.001254730807221768, 0.000433514280597531, -0.000445673862380164, -0.001123137180667268, -0.001419612701203994,
+-0.001281535037100789, -0.000785797405770491, -0.000106146183328305, 0.000545624937191001, 0.000984325470442889,
+ 0.001102541594699144, 0.000894687281371102, 0.000449422013818846, -0.000084459306793206, -0.000546326732285124,
+-0.000810918218693337, -0.000820930704466417, -0.000597014064504330, -0.000224481053594759, 0.000177179393286866,
+ 0.000491558598565883, 0.000638042870263572, 0.000591123735768924, 0.000382180878613336, 0.000085048027839757,
+-0.000208868052760534, -0.000417820101680067, -0.000491443283168306, -0.000421527417296624, -0.000240063519947365,
+-0.000006554284588476, 0.000210686954436390, 0.000353469185042608, 0.000387771231401110, 0.000309776397278667,
+ 0.000143339868281261, -0.000069269573936326, -0.000279964105369211, -0.000447038893351438, -0.000543922161049598,
+-0.000562800094080439, -0.000513090543707066, -0.000416082361724969, -0.000297836387286273, -0.000182447830402188,
+-0.000087256395370183, -0.000020835366942643, 0.000016460532579755, 0.000030165284908057, 0.000028547330106604,
+ 0.000019798433756403, 0.000011951828200011 };
+
 // Sample 48 kHz, pass 10, stop 12, ripple 0.1 dB, atten 100 dB.
 double quiskFilt48dec24Coefs[98] = { 0.000036864882767612, 0.000009858596392836, -0.000330770380800406, -0.001009174072411182,
 -0.001404963853116591, -0.000770236458542885, 0.000523955998497470, 0.000947009978368078, -0.000170647420729277, -0.001215337186275615,
