@@ -56,6 +56,7 @@ class Hardware(BaseHardware):
     self.index = 0
     self.mode = None
     self.band = None
+    self.rf_gain = 0
     self.HiQSDR_Connector_X1 = 0
     self.HiQSDR_Attenuator = 0
     self.HiQSDR_Bits = 0
@@ -84,6 +85,8 @@ class Hardware(BaseHardware):
       self.rx_udp_socket = None
   def ReturnFrequency(self):	# Return the current tuning and VFO frequency
     return None, None		# frequencies have not changed
+  def ReturnVfoFloat(self):	# Return the accurate VFO as a float
+    return float(self.rx_phase) * self.conf.rx_udp_clock / 2.0**32
   def ChangeFrequency(self, tx_freq, vfo_freq, source='', band='', event=None):
     if vfo_freq != self.vfo_frequency:
       self.vfo_frequency = vfo_freq
@@ -102,7 +105,9 @@ class Hardware(BaseHardware):
       pass
     elif mode in ("CWL", "CWU"):
       self.tx_control |= 0x01
-    elif mode in ("USB", "LSB", "AM", "FM", "DGTL"):
+    elif mode in ("USB", "LSB", "AM", "FM"):
+      self.tx_control |= 0x02
+    elif mode[0:4] == 'DGT-':
       self.tx_control |= 0x02
     elif mode[0:3] == 'IMD':
       self.tx_control |= 0x02
@@ -118,7 +123,7 @@ class Hardware(BaseHardware):
   def SetTxLevel(self):
     if self.vna_count:
       return
-    elif self.mode == 'DGTL':
+    elif self.mode[0:4] == 'DGT-':
       self.tx_level = self.conf.digital_tx_level
     else:
       try:
@@ -132,17 +137,23 @@ class Hardware(BaseHardware):
     self.HiQSDR_Connector_X1 &= ~0x10	# Mask in the preamp bit
     if n == 0:		# 0dB
       self.HiQSDR_Attenuator = 0
+      self.rf_gain = 0
     elif n == 1:	# +10
       self.HiQSDR_Attenuator = 0
       self.HiQSDR_Connector_X1 |= 0x10
+      self.rf_gain = 10
     elif n == 2:	# -10
       self.HiQSDR_Attenuator = 0x08
+      self.rf_gain = -10
     elif n == 3:	# -20
       self.HiQSDR_Attenuator = 0x10
+      self.rf_gain = -20
     elif n == 4:	# -30
       self.HiQSDR_Attenuator = 0x18
+      self.rf_gain = -30
     else:
       self.HiQSDR_Attenuator = 0
+      self.rf_gain = 0
       print 'Unknown RfGain'
     self.NewUdpStatus()
   def OnButtonPTT(self, event):
