@@ -350,7 +350,7 @@ static int tx_filter(complex * filtered, int count, int is_cpx)
 	return count;
 }
 
-static int tx_filter_digital(complex * filtered, int count)
+static int tx_filter_digital(complex * filtered, int count, double volume)
 {	// Input samples are creal(filtered), output is filtered.
 	// This filter has minimal processing and is used for digital modes.
 	int i;
@@ -358,15 +358,14 @@ static int tx_filter_digital(complex * filtered, int count)
 	complex csample;
 
 	static struct quisk_dFilter filter1;
-	static int do_init = 1;
 #if DEBUG_IO
 	double x;
 	static double peakIn = 0, peakOut2 = 0;		// input/output level
 #endif
-	if (do_init) {		// initialization
-		do_init = 0;
+	if (!filtered) {		// initialization
 		quisk_filt_dInit(&filter1, quiskMicFilt48Coefs, sizeof(quiskMicFilt48Coefs)/sizeof(double));
-		quisk_filt_tune(&filter1, 1650.0 / 48000, 1);
+		quisk_filt_tune(&filter1, 1650.0 / 48000, rxMode != 2);
+		return 0;
 	}
 #if DEBUG_IO
 	//QuiskPrintTime("", -2);
@@ -387,7 +386,7 @@ static int tx_filter_digital(complex * filtered, int count)
 #endif
 		if (amplitude > 1.0)
 			csample /= amplitude;
-		filtered[i] = csample * CLIP16;		// convert back to 16 bits
+		filtered[i] = csample * CLIP16 * volume;		// convert back to 16 bits
 	}
 
 //printf("%5.2lf\n", increasing);
@@ -632,7 +631,11 @@ int quisk_process_microphone(int mic_sample_rate, complex * cSamples, int count)
 		switch (rxMode) {
 		case 2:		// LSB
 		case 3:		// USB
-			if (spotLevel == 0) {
+			if (quisk_record_state == PLAYBACK) {
+				count = tx_filter_digital(cSamples, count, 0.9);	// filter samples, minimal processing
+				transmit_udp(cSamples, count);
+			}
+			else if (spotLevel == 0) {
 				count = tx_filter(cSamples, count, 1);	// filter samples
 				transmit_udp(cSamples, count);
 			}
@@ -642,21 +645,25 @@ int quisk_process_microphone(int mic_sample_rate, complex * cSamples, int count)
 			}
 			break;
 		case 4:		// AM
-			count = tx_filter(cSamples, count, 0);
+			if (quisk_record_state != PLAYBACK)		// no audio processing for recorded sound
+				count = tx_filter(cSamples, count, 0);
 			for (i = 0; i < count; i++)	// transmit (0.5 + ampl/2, 0)
 				cSamples[i] = (creal(cSamples[i]) + CLIP16) * 0.5;
 			transmit_udp(cSamples, count);
 			break;
 		case 5:		// FM
-			count = tx_filter(cSamples, count, 0);
+			if (quisk_record_state != PLAYBACK)		// no audio processing for recorded sound
+				count = tx_filter(cSamples, count, 0);
 			for (i = 0; i < count; i++) {	// this is phase modulation == FM and 6 dB /octave preemphasis
 				cSamples[i] = CLIP16 * cexp(I * creal(cSamples[i]) / CLIP16 * modulation_index);
 			}
   			transmit_udp(cSamples, count);
   			break;
-		case 7:		// DGTL
+		case 7:		// digital modes
+		case 8:
+		case 9:
 			if (spotLevel == 0) {
-				count = tx_filter_digital(cSamples, count);	// filter samples, minimal processing
+				count = tx_filter_digital(cSamples, count, 1.0);	// filter samples, minimal processing
 				transmit_udp(cSamples, count);
 			}
 			else {
@@ -757,6 +764,7 @@ void quisk_open_mic(void)
 void quisk_set_tx_mode(void)	// called when the mode rxMode is changed
 {
 	tx_filter(NULL, 0, 0);
+	tx_filter_digital(NULL, 0, 0.0);
 #ifdef TEST_TX_WAV_FILE
 	if (!wavFp)			// convenient place to open file
 		open_wav();
