@@ -4,33 +4,33 @@
 
 import sys
 from n2adr import quisk_hardware
-from n2adr import quisk_widgets
+#from n2adr import quisk_widgets
 
 if sys.platform == "win32":
   name_of_sound_play = 'Primary'
-  microphone_name    = "AK5370"
+  microphone_name    = "Microphone"
   latency_millisecs = 150
   data_poll_usec = 20000
+  favorites_file_path = "C:/pub/quisk_favorites.txt"
 elif 0:		# portaudio devices
   name_of_sound_play = 'portaudio:hw:0'
   microphone_name = "portaudio:AK5370"
   latency_millisecs = 150
   data_poll_usec = 5000
-  digital_input_name = 'portaudio:hw:2,0'
-  digital_output_name = digital_input_name
+  favorites_file_path = "/home/jim/pub/quisk_favorites.txt"
 else:		# alsa devices
   name_of_sound_play = 'hw:0'
   microphone_name = "alsa:AK5370"
   latency_millisecs = 150
   data_poll_usec = 5000
-  digital_input_name =  'hw:Loopback,0'
-  digital_output_name = 'hw:Loopback,0'
+  favorites_file_path = "/home/jim/pub/quisk_favorites.txt"
 
 mic_clip = 2.0			# 3.0
 mic_preemphasis = 0.6		# 0.6
-mic_sample_rate = 8000
+mic_sample_rate = 48000
 playback_rate = 48000
 agc_off_gain = 80
+tx_level = {None:120, '40':120}
 
 default_screen = 'WFall'
 waterfall_y_scale = 80
