@@ -40,13 +40,14 @@ static fft_data * FFT1, * FFT2, * FFT3;	// data for three fft's		WB4JFI ADD thir
 static fft_data * ptWriteFft;		// Write the current samples to this fft
 static double * fft_avg;		// Array to average the FFT
 static double * fft_window;		// Window for FFT data
+static double * current_graph;	// current graph data as returned
 static int use_remove_dc=1;		// Remove DC from samples
 
 static PyObject * QuiskError;		// Exception for this module
 static PyObject * pyApp;		// Application instance
 static int fft_size;			// size of fft, e.g. 1024
 int data_width;				// number of points to return as graph data; fft_size * n
-int rxMode;				// 0 to 7, 10 to 12: CWL, CWU, LSB, USB, AM, FM, EXT, DGTL, IMD(10 to 12)
+int rxMode;				// 0 to 9, 10 to 12: CWL, CWU, LSB, USB, AM, FM, EXT, DGT-U, DGT-L, DGT-IQ, IMD(10 to 12)
 int quisk_noise_blanker;		// noise blanker level, 0 for off
 PyObject * quisk_pyConfig=NULL;	// Configuration module instance
 long quisk_mainwin_handle;		// Handle of the main window
@@ -77,13 +78,13 @@ static int agcInUse;			// 0 for no AGC
 static double agcRelease, agcLevel;	// AGC parameters
 static double agcMaxGain;		// Max AGC gain
 static double agcOffGain;		// Gain when AGC is off
-static double agcGain;			// Volume level control for audio output
+static double squelch_level;		// setting of squelch control
 static int quisk_invert_spectrum = 0;	// Invert the input RF spectrum
 
 static double Smeter;			// Measured RMS signal strength
 static int rx_tune_freq;		// Receive tuning frequency as +/- sample_rate / 2
 int quisk_tx_tune_freq;			// Transmit tuning frequency as +/- sample_rate / 2
-static int rit_freq;					// RIT frequency in Hertz
+static int rit_freq;			// RIT frequency in Hertz
 
 #define RX_UDP_SIZE		1442		// Expected size of UDP samples packet
 static int rx_udp_socket = INVALID_SOCKET;		// Socket for receiving ADC samples from UDP
@@ -95,7 +96,20 @@ static int rx_udp_read_blocks = 0;	// Number of blocks to read for each read cal
 
 static int is_little_endian;		// Test byte order; is it little-endian?
 
-static int fDecimate(double * dSamples, int nSamples, double fdecim)
+enum quisk_rec_state quisk_record_state = IDLE;
+static float * quisk_record_buffer;
+static int quisk_record_bufsize;
+static int quisk_record_index;
+static int quisk_play_index;
+static int quisk_mic_index;
+static int quisk_record_full;
+
+// These are used to measure the frequency of a continuous RF signal.
+static void measure_freq(complex *, int, int);
+static double measured_frequency;
+static int measure_freq_mode=0;
+
+static int fFracDecim(double * dSamples, int nSamples, double fdecim)
 {
 	int i, nout;
 	double xm0, xm1, xm2, xm3;
@@ -107,7 +121,7 @@ static int fDecimate(double * dSamples, int nSamples, double fdecim)
 	nout = 0;
 	for (i = 0; i < nSamples; i++) {
 		y3 = dSamples[i];
-		if (dindex < 1 || dindex >= 2.2)
+		if (dindex < 1 || dindex >= 2.4)
 			printf ("dindex %.5f  fdecim %.8f\n", dindex, fdecim);
 		if (dindex < 2) {
 #if 0
@@ -127,7 +141,7 @@ static int fDecimate(double * dSamples, int nSamples, double fdecim)
 			y2 = y3;
 		}
 		else {
-			if (dindex > 2.3) printf ("Skip at %.2f\n", dindex);
+			if (dindex > 2.5) printf ("Skip at %.2f\n", dindex);
 			y0 = y1;
 			y1 = y2;
 			y2 = y3;
@@ -137,6 +151,51 @@ static int fDecimate(double * dSamples, int nSamples, double fdecim)
 	//printf ("in %d out %d\n", in, out);
 	return nout;
 }
+
+static int cFracDecim(complex * cSamples, int nSamples, double fdecim)
+{
+// Fractional decimation of I/Q signals works poorly because it introduces aliases and birdies.
+	int i, nout;
+	double xm0, xm1, xm2, xm3;
+	static double dindex = 1;
+	static complex c0=0, c1=0, c2=0, c3=0;
+	static int in=0, out=0;
+
+	in += nSamples;
+	nout = 0;
+	for (i = 0; i < nSamples; i++) {
+		c3 = cSamples[i];
+		if (dindex < 1 || dindex >= 2.4)
+			printf ("dindex %.5f  fdecim %.8f\n", dindex, fdecim);
+		if (dindex < 2) {
+#if 0
+				cSamples[nout++] = (1 - (dindex - 1)) * c1 + (dindex - 1) * c2;
+#else
+				xm0 = dindex - 0;
+				xm1 = dindex - 1;
+				xm2 = dindex - 2;
+				xm3 = dindex - 3;
+				cSamples[nout++] =
+					(xm1 * xm2 * xm3 * c0 / -6.0 + xm0 * xm2 * xm3 * c1 / 2.0 +
+					xm0 * xm1 * xm3 * c2 / -2.0 + xm0 * xm1 * xm2 * c3 / 6.0);
+#endif
+			out++;
+			dindex += fdecim - 1;
+			c0 = c1;
+			c1 = c2;
+			c2 = c3;
+		}
+		else {
+			if (dindex > 2.5) printf ("Skip at %.2f\n", dindex);
+			c0 = c1;
+			c1 = c2;
+			c2 = c3;
+			dindex -= 1;
+		}
+	}
+	//printf ("in %d out %d\n", in, out);
+	return nout;
+}
 			
 #define QUISK_NB_HWINDOW_SECS	500.E-6	// half-size of blanking window in seconds
 static void NoiseBlanker(complex * cSamples, int nSamples)
@@ -323,6 +382,114 @@ static void AddTestTone(complex * cSamples, int nSamples)
 	}
 }
 
+static int IsSquelch(int freq)
+{  // measure the signal level for squelch
+	int i, i1, i2, width;
+	double meter;
+
+	width = 5000 * data_width / sample_rate;	// bandwidth determines number of pixels to average
+	i1 = (int)((double)freq * data_width / sample_rate + data_width / 2.0 - width / 2.0 + 0.5);
+	i2 = i1 + width;
+	meter = 0;
+	if (i1 >= 0 && i2 < data_width) {	// too close to edge?
+		for (i = i1; i < i2; i++) {
+			meter += current_graph[i];
+		}
+	}
+	meter /= width;
+	if (meter == 0 || meter < squelch_level)
+		return 1;   // meter == 0 means Rx freq is off-screen so squelch is on
+	else
+		return 0;
+}
+
+static PyObject * set_record_state(PyObject * self, PyObject * args)
+{  // called when a Record or Play button is pressed, or with -1 to poll
+	int button;
+
+	if (!PyArg_ParseTuple (args, "i", &button))
+		return NULL;
+	switch (button) {
+	case 0:			// press record
+		if ( ! quisk_record_buffer) {	// initialize
+			quisk_record_bufsize = (int)(QuiskGetConfigDouble("max_record_minutes", 0.25) * quisk_sound_state.playback_rate * 60.0 + 0.2);
+			quisk_record_buffer = (float *)malloc(sizeof(float) * quisk_record_bufsize);
+		}
+		quisk_record_index = 0;
+		quisk_play_index = 0;
+		quisk_mic_index = 0;
+		quisk_record_full = 0;
+		quisk_record_state = RECORD;
+		break;
+	case 1:			// release record
+		quisk_record_state = IDLE;
+		break;
+	case 2:			// press play
+		if (quisk_record_full) {
+			quisk_play_index = quisk_record_index + 1;
+			if (quisk_play_index >= quisk_record_bufsize)
+				quisk_play_index = 0;
+		}
+		else {
+			quisk_play_index = 0;
+		}
+		quisk_mic_index = quisk_play_index;
+		quisk_record_state = PLAYBACK;
+		break;
+	case 3:			// release play
+		quisk_record_state = IDLE;
+		break;
+	}
+	return PyInt_FromLong(quisk_record_state != PLAYBACK);
+}
+
+static void tmp_record(complex * cSamples, int nSamples, double agcGain)		// save radio sound
+{
+	int i;
+
+	for (i = 0; i < nSamples; i++) {
+		quisk_record_buffer[quisk_record_index++] = creal(cSamples[i]) * agcGain;
+		if (quisk_record_index >= quisk_record_bufsize) {
+			quisk_record_index = 0;
+			quisk_record_full = 1;
+		}
+	}
+}
+
+static void tmp_playback(complex * cSamples, int nSamples, double volume)
+{  // replace radio sound with saved sound
+	int i;
+	double d;
+
+	for (i = 0; i < nSamples; i++) {
+		d = quisk_record_buffer[quisk_play_index++] * volume;
+		cSamples[i] = d + I * d;
+		if (quisk_play_index >= quisk_record_bufsize)
+			quisk_play_index = 0;
+		if (quisk_play_index == quisk_record_index) {
+			quisk_record_state = IDLE;
+			return;
+		}
+	}
+}
+
+void quisk_tmp_microphone(complex * cSamples, int nSamples)
+{  // replace microphone samples with saved sound
+	int i;
+	double d;
+
+	for (i = 0; i < nSamples; i++) {
+		d = quisk_record_buffer[quisk_mic_index++];
+		cSamples[i] = d + I * d;
+		if (quisk_mic_index >= quisk_record_bufsize)
+			quisk_mic_index = 0;
+		if (quisk_mic_index == quisk_record_index) {
+			quisk_record_state = IDLE;
+			return;
+		}
+	}
+}
+
 int quisk_process_samples(complex * cSamples, int nSamples)
 {
 // Called when samples are available.
@@ -334,6 +501,7 @@ int quisk_process_samples(complex * cSamples, int nSamples)
 	double dsamples[SAMP_BUFFER_SIZE];
 
 	static double FM_www, FM_nnn, FM_a_0, FM_a_1, FM_b_1, FM_x_1, FM_y_1;   // filter for FM
+	static double agcGain;			// Volume level control for audio output
 	static complex tuneVector = 1;
 	static complex sidetoneVector = BIG_VOLUME;
 	static double dOutCounter = 0;		// Cumulative net output samples for sidetone etc.
@@ -341,6 +509,7 @@ int quisk_process_samples(complex * cSamples, int nSamples)
 	static double sidetoneEnvelope;		// Shape the rise and fall times of the sidetone
 	static double keyupEnvelope = 1.0;	// Shape the rise time on key up
 	static int playSilence;
+	static int is_squelch = 0;		// Are we squelched?
 	static complex fm_1 = 10;		// Sample delayed by one
 	static double dc_remove;		// DC removal for AM
 	static struct quisk_cHB45Filter HalfBand1 = {NULL, 0, 0};
@@ -352,11 +521,12 @@ int quisk_process_samples(complex * cSamples, int nSamples)
 	static struct quisk_dHB45Filter HalfBand7 = {NULL, 0, 0};
 	static struct quisk_dHB45Filter HalfBand8 = {NULL, 0, 0};
 	static struct quisk_dHB45Filter HalfBand9 = {NULL, 0, 0};
-	static struct quisk_cFilter filtSdriq2 = {NULL};
-	static struct quisk_cFilter filtSdriq4;
-	static struct quisk_cFilter filtSdriq5;
-	static struct quisk_cFilter filtSdriq7;
+	static struct quisk_cFilter filtSdriq111 = {NULL};
+	static struct quisk_cFilter filtSdriq53;
+	static struct quisk_cFilter filtSdriq133;
+	static struct quisk_cFilter filtSdriq185;
 	static struct quisk_cFilter filtDecim5;
+	static struct quisk_cFilter filtDecim5S;
 	static struct quisk_cFilter filtDecim48to24;
 	static struct quisk_dFilter filtAudio24p3;
 	static struct quisk_dFilter filtAudio24p4;
@@ -377,12 +547,13 @@ int quisk_process_samples(complex * cSamples, int nSamples)
 		printit = 0;
 	}
 #endif
-	if ( ! filtSdriq2.dCoefs) {	// Initialize all filters
-		quisk_filt_cInit(&filtSdriq2, quiskFilt53D2Coefs, sizeof(quiskFilt53D2Coefs)/sizeof(double));
-		quisk_filt_cInit(&filtSdriq4, quiskFilt111D4Coefs, sizeof(quiskFilt111D4Coefs)/sizeof(double));
-		quisk_filt_cInit(&filtSdriq5, quiskFilt133D5Coefs, sizeof(quiskFilt133D5Coefs)/sizeof(double));
-		quisk_filt_cInit(&filtSdriq7, quiskFilt185D7Coefs, sizeof(quiskFilt185D7Coefs)/sizeof(double));
+	if ( ! filtSdriq111.dCoefs) {	// Initialize all filters
+		quisk_filt_cInit(&filtSdriq111, quiskFilt111D2Coefs, sizeof(quiskFilt111D2Coefs)/sizeof(double));
+		quisk_filt_cInit(&filtSdriq53, quiskFilt53D1Coefs, sizeof(quiskFilt53D1Coefs)/sizeof(double));
+		quisk_filt_cInit(&filtSdriq133, quiskFilt133D2Coefs, sizeof(quiskFilt133D2Coefs)/sizeof(double));
+		quisk_filt_cInit(&filtSdriq185, quiskFilt185D3Coefs, sizeof(quiskFilt185D3Coefs)/sizeof(double));
 		quisk_filt_cInit(&filtDecim5, quiskFilt240D5Coefs, sizeof(quiskFilt240D5Coefs)/sizeof(double));
+		quisk_filt_cInit(&filtDecim5S, quiskFilt240D5CoefsSharp, sizeof(quiskFilt240D5CoefsSharp)/sizeof(double));
 		quisk_filt_cInit(&filtDecim48to24, quiskFilt48dec24Coefs, sizeof(quiskFilt48dec24Coefs)/sizeof(double));
 		quisk_filt_dInit(&filtAudio24p3,  quiskAudio24p3Coefs, sizeof(quiskAudio24p3Coefs)/sizeof(double));
 		quisk_filt_dInit(&filtAudio24p4,  quiskAudio24p4Coefs, sizeof(quiskAudio24p4Coefs)/sizeof(double));
@@ -551,83 +722,78 @@ int quisk_process_samples(complex * cSamples, int nSamples)
 	}
 #endif
 
-	// Decimate: Lower the sample rate to 24000 sps (or approx).  Filters are designed for
-	// a pass bandwidth of 10 kHz and a stop bandwidth of 12 kHz.
-	final_filter = rxMode == 4 || rxMode == 5;	// Use sharp FIR final filter for decimate by 2
+	// Decimate: Lower the sample rate to 48000 sps (or approx).  Filters are designed for
+	// a pass bandwidth of 20 kHz and a stop bandwidth of 24 kHz.
+	// We use 48 ksps to accommodate wide digital modes.
+	// If you change this, correct the rates in get_filter_rate.
+	final_filter = (rxMode == 7 || rxMode == 8 || rxMode == 9);	// Use sharp FIR final filter for decimate
 	double_filter_decim = 1.0;
+	filter_srate = 48000;
 	switch((quisk_sound_state.sample_rate + 100) / 1000) {
-	case 24:
-		break;
 	case 41:
 	case 48:
-		if (final_filter)
-			nSamples = quisk_cDecimate(cSamples, nSamples, &filtDecim48to24, 2);
-		else
-			nSamples = quisk_cDecim2HB45(cSamples, nSamples, &HalfBand5);
 		break;
 	case 53:	// SDR-IQ
-		nSamples = quisk_cDecimate(cSamples, nSamples, &filtSdriq2, 2);
-		double_filter_decim = quisk_sound_state.sample_rate / 2.0 / 24000.0;
+		filter_srate = quisk_sound_state.sample_rate;
+		double_filter_decim = filter_srate / 48000.0;
+		nSamples = quisk_cDecimate(cSamples, nSamples, &filtSdriq53, 1);
 		break;
 	case 96:
-		nSamples = quisk_cDecim2HB45(cSamples, nSamples, &HalfBand1);
 		if (final_filter)
 			nSamples = quisk_cDecimate(cSamples, nSamples, &filtDecim48to24, 2);
 		else
-			nSamples = quisk_cDecim2HB45(cSamples, nSamples, &HalfBand5);
+			nSamples = quisk_cDecim2HB45(cSamples, nSamples, &HalfBand1);
 		break;
 	case 111:	// SDR-IQ
-		nSamples = quisk_cDecimate(cSamples, nSamples, &filtSdriq4, 4);
-		double_filter_decim = quisk_sound_state.sample_rate / 4.0 / 24000.0;
+		filter_srate = quisk_sound_state.sample_rate / 2;
+		double_filter_decim = filter_srate / 48000.0;
+		nSamples = quisk_cDecimate(cSamples, nSamples, &filtSdriq111, 2);
 		break;
 	case 133:	// SDR-IQ
-		nSamples = quisk_cDecimate(cSamples, nSamples, &filtSdriq5, 5);
-		double_filter_decim = quisk_sound_state.sample_rate / 5.0 / 24000.0;
+		filter_srate = quisk_sound_state.sample_rate / 2;
+		double_filter_decim = filter_srate / 48000.0;
+		nSamples = quisk_cDecimate(cSamples, nSamples, &filtSdriq133, 2);
 		break;
 	case 185:	// SDR-IQ
-		nSamples = quisk_cDecimate(cSamples, nSamples, &filtSdriq7, 7);
-		double_filter_decim = quisk_sound_state.sample_rate / 7.0 / 24000.0;
+		filter_srate = quisk_sound_state.sample_rate / 3;
+		double_filter_decim = filter_srate / 48000.0;
+		nSamples = quisk_cDecimate(cSamples, nSamples, &filtSdriq185, 3);
 		break;
 	case 192:
-		nSamples = quisk_cDecim2HB45(cSamples, nSamples, &HalfBand1);
 		nSamples = quisk_cDecim2HB45(cSamples, nSamples, &HalfBand2);
 		if (final_filter)
 			nSamples = quisk_cDecimate(cSamples, nSamples, &filtDecim48to24, 2);
 		else
-			nSamples = quisk_cDecim2HB45(cSamples, nSamples, &HalfBand5);
+			nSamples = quisk_cDecim2HB45(cSamples, nSamples, &HalfBand1);
 		break;
 	case 240:
-		nSamples = quisk_cDecimate(cSamples, nSamples, &filtDecim5, 5);
 		if (final_filter)
-			nSamples = quisk_cDecimate(cSamples, nSamples, &filtDecim48to24, 2);
+			nSamples = quisk_cDecimate(cSamples, nSamples, &filtDecim5S, 5);
 		else
-			nSamples = quisk_cDecim2HB45(cSamples, nSamples, &HalfBand5);
+			nSamples = quisk_cDecimate(cSamples, nSamples, &filtDecim5, 5);
 		break;
 	case 384:
-		nSamples = quisk_cDecim2HB45(cSamples, nSamples, &HalfBand1);
 		nSamples = quisk_cDecim2HB45(cSamples, nSamples, &HalfBand2);
 		nSamples = quisk_cDecim2HB45(cSamples, nSamples, &HalfBand3);
 		if (final_filter)
 			nSamples = quisk_cDecimate(cSamples, nSamples, &filtDecim48to24, 2);
 		else
-			nSamples = quisk_cDecim2HB45(cSamples, nSamples, &HalfBand5);
+			nSamples = quisk_cDecim2HB45(cSamples, nSamples, &HalfBand1);
 		break;
 	case 480:
-		nSamples = quisk_cDecim2HB45(cSamples, nSamples, &HalfBand1);
 		nSamples = quisk_cDecimate(cSamples, nSamples, &filtDecim5, 5);
 		if (final_filter)
 			nSamples = quisk_cDecimate(cSamples, nSamples, &filtDecim48to24, 2);
 		else
-			nSamples = quisk_cDecim2HB45(cSamples, nSamples, &HalfBand5);
+			nSamples = quisk_cDecim2HB45(cSamples, nSamples, &HalfBand1);
 		break;
 	case 960:
-		nSamples = quisk_cDecim2HB45(cSamples, nSamples, &HalfBand1);
 		nSamples = quisk_cDecim2HB45(cSamples, nSamples, &HalfBand2);
 		nSamples = quisk_cDecimate(cSamples, nSamples, &filtDecim5, 5);
 		if (final_filter)
 			nSamples = quisk_cDecimate(cSamples, nSamples, &filtDecim48to24, 2);
 		else
-			nSamples = quisk_cDecim2HB45(cSamples, nSamples, &HalfBand5);
+			nSamples = quisk_cDecim2HB45(cSamples, nSamples, &HalfBand1);
 		break;
 	default:
 		printf ("Failure in quisk.c in integer decimation\n");
@@ -642,11 +808,16 @@ int quisk_process_samples(complex * cSamples, int nSamples)
 	}
 #endif
 
+	if (measure_freq_mode)
+		measure_freq(cSamples, nSamples, filter_srate);
+
 	// Filter and demodulate signal, copy capture buffer cSamples to play buffer dsamples.
 	// filter_srate is the sample rate after integer decimation.
 	filter_srate = 24000;
+	// If you change this, correct the rates in get_filter_rate.
 	switch(rxMode) {
 	case 0:		// lower sideband CW at 6 ksps
+		nSamples = quisk_cDecim2HB45(cSamples, nSamples, &HalfBand5);
 		nSamples = quisk_cDecim2HB45(cSamples, nSamples, &HalfBand4);
 		nSamples = quisk_cDecimate(cSamples, nSamples, &filtDecim48to24, 2);
 		for (i = 0; i < nSamples; i++) {
@@ -657,6 +828,7 @@ int quisk_process_samples(complex * cSamples, int nSamples)
 		nSamples = quisk_dInterp2HB45(dsamples, nSamples, &HalfBand6);
 		break;
 	case 1:		// upper sideband CW at 6 ksps
+		nSamples = quisk_cDecim2HB45(cSamples, nSamples, &HalfBand5);
 		nSamples = quisk_cDecim2HB45(cSamples, nSamples, &HalfBand4);
 		nSamples = quisk_cDecimate(cSamples, nSamples, &filtDecim48to24, 2);
 		for (i = 0; i < nSamples; i++) {
@@ -667,6 +839,7 @@ int quisk_process_samples(complex * cSamples, int nSamples)
 		nSamples = quisk_dInterp2HB45(dsamples, nSamples, &HalfBand6);
 		break;
 	case 2:	 // lower sideband SSB at 12 ksps
+		nSamples = quisk_cDecim2HB45(cSamples, nSamples, &HalfBand5);
 		nSamples = quisk_cDecimate(cSamples, nSamples, &filtDecim48to24, 2);
 		for (i = 0; i < nSamples; i++) {
 			cx = cRxFilterOut(cSamples[i]);
@@ -675,8 +848,8 @@ int quisk_process_samples(complex * cSamples, int nSamples)
 		nSamples = quisk_dInterpolate(dsamples, nSamples, &filtAudio24p4, 2);
 		break;
 	case 3:	 // upper sideband SSB at 12 ksps
-	case 7:
 	default:
+		nSamples = quisk_cDecim2HB45(cSamples, nSamples, &HalfBand5);
 		nSamples = quisk_cDecimate(cSamples, nSamples, &filtDecim48to24, 2);
 		for (i = 0; i < nSamples; i++) {
 			cx = cRxFilterOut(cSamples[i]);
@@ -685,6 +858,7 @@ int quisk_process_samples(complex * cSamples, int nSamples)
 		nSamples = quisk_dInterpolate(dsamples, nSamples, &filtAudio24p4, 2);
 		break;
 	case 4:		// AM at 24 ksps
+		nSamples = quisk_cDecimate(cSamples, nSamples, &filtDecim48to24, 2);
 		for (i = 0; i < nSamples; i++) {
 			cx = dRxFilterOut(cSamples[i]);
 			di = cabs(cx);
@@ -696,6 +870,7 @@ int quisk_process_samples(complex * cSamples, int nSamples)
 		nSamples = quisk_dFilter(dsamples, nSamples, &filtAudio24p6);
 		break;
 	case 5:		// FM at 24 ksps
+		nSamples = quisk_cDecimate(cSamples, nSamples, &filtDecim48to24, 2);
 		for (i = 0; i < nSamples; i++) {
 			cx = dRxFilterOut(cSamples[i]);
 			cpx = cx * conj(fm_1);
@@ -709,6 +884,27 @@ int quisk_process_samples(complex * cSamples, int nSamples)
 		nSamples = quisk_dFilter(dsamples, nSamples, &filtAudioFmHp);
 		nSamples = quisk_dInterp2HB45(dsamples, nSamples, &HalfBand6);
 		break;
+	case 7:     // digital mode DGT-U at 48 ksps
+		filter_srate = 48000;
+		for (i = 0; i < nSamples; i++) {
+			cx = cRxFilterOut(cSamples[i]);
+			dsamples[i] = creal(cx) - cimag(cx);
+		}
+		break;
+	case 8:     // digital mode DGT-L at 48 ksps
+		filter_srate = 48000;
+		for (i = 0; i < nSamples; i++) {
+			cx = cRxFilterOut(cSamples[i]);
+			dsamples[i] = creal(cx) + cimag(cx);
+		}
+		break;
+	case 9:     // digital mode DGT-IQ at 48 ksps
+		filter_srate = 48000;
+		if (filter_bandwidth < 19000) {		// No filtering for wide bandwidth
+			for (i = 0; i < nSamples; i++)
+				cSamples[i] = dRxFilterOut(cSamples[i]);
+		}
+		break;
 	}
 #if DEBUG
 	for (i = 0; i < nSamples; i++) {
@@ -719,8 +915,12 @@ int quisk_process_samples(complex * cSamples, int nSamples)
 #endif
 
 	// Perhaps decimate by an additional fraction
-	if (double_filter_decim != 1.0)
-		nSamples = fDecimate(dsamples, nSamples, double_filter_decim);
+	if (double_filter_decim != 1.0) {
+		if (rxMode == 9)		// DGT-IQ stereo sound
+			nSamples = cFracDecim(cSamples, nSamples, double_filter_decim);
+		else
+			nSamples = fFracDecim(dsamples, nSamples, double_filter_decim);
+	}
 #if DEBUG
 	for (i = 0; i < nSamples; i++) {
 		d = fabs(dsamples[i]);
@@ -753,12 +953,26 @@ int quisk_process_samples(complex * cSamples, int nSamples)
 #endif
 	// Find the peak signal amplitude, copy sound to output cSamples
 	agcPeak = 0;
-	for (i = 0; i < nSamples; i++) {
-		d = dsamples[i];
-		cSamples[i] = d + I * d;	// monophonic sound, two channels
-		d = fabs(d);
-		if (agcPeak < d)
-			agcPeak = d;
+	if (rxMode == 9) {		// DGT-IQ stereo sound
+		for (i = 0; i < nSamples; i++) {
+			d = creal(cSamples[i]);
+			d = fabs(d);
+			if (agcPeak < d)
+				agcPeak = d;
+			d = cimag(cSamples[i]);
+			d = fabs(d);
+			if (agcPeak < d)
+				agcPeak = d;
+		}
+	}
+	else {					// monophonic sound
+		for (i = 0; i < nSamples; i++) {
+			d = dsamples[i];
+			cSamples[i] = d + I * d;	// monophonic sound, two channels
+			d = fabs(d);
+			if (agcPeak < d)
+				agcPeak = d;
+		}
 	}
 start_agc:
 	// Normalize peak amplitude to 1.0 maximum
@@ -773,7 +987,7 @@ start_agc:
 	if (di > 1.0)
 		di = 1.0;
 	// The current output if agcGain is not changed is agcPeak * agcGain
-	if (rxMode == 5) {
+	if (rxMode == 5) {		// mode is FM
 		// Brick wall agc; make all signals the same volume
 		if (agcPeak * agcGain >= 1.0)	// clipping
 			agcGain = 0.5 / agcPeak;
@@ -800,12 +1014,32 @@ start_agc:
 		d = CLIP32;
 		printf("agcGain %12.1lf  agcMaxGain * agcLevel %.1lf  agcPeak %.6lf agcOffGain %.1lf\n",
 			agcGain, agcMaxGain * agcLevel, agcPeak / 2.e9, agcOffGain);
-		printf ("Levels: %12.8lf  %12.8lf %12.8lf  %12.8lf  %12.8lf\n",
-			levelA/d, levelB/d, levelC/d, levelD/d, levelE/d);
+		//printf ("Levels: %12.8lf  %12.8lf %12.8lf  %12.8lf  %12.8lf\n",
+		//	levelA/d, levelB/d, levelC/d, levelD/d, levelE/d);
 		levelA = levelB = levelC = levelD = levelE = 0;
 	}
 #endif
-	agc_level = agcGain * audioVolume;
+	if (rxMode == 5) {		// mode is FM
+		if (IsSquelch(quisk_tx_tune_freq)) {
+			agc_level = 0;
+#if DEBUG
+			if ( ! is_squelch)
+				printf("close squelch\n");
+#endif
+			is_squelch = 1;
+		}
+		else {
+			agc_level = agcGain * audioVolume;
+#if DEBUG
+			if (is_squelch)
+				printf("open  squelch\n");
+#endif
+			is_squelch = 0;
+		}
+	}
+	else {
+		agc_level = agcGain * audioVolume;
+	}
 	if (keyupEnvelope < 1.0) {		// raise volume slowly after the key goes up
 		di = 1. / (quisk_sound_state.playback_rate * 5e-3);		// 5 milliseconds
 		for (i = 0; i < nSamples; i++) {
@@ -815,9 +1049,13 @@ start_agc:
 			cSamples[i] *= keyupEnvelope * agc_level;
 		}
 	}
-	else {		// apply AGC
+	else {
+		if (quisk_record_state == RECORD && ! is_squelch)
+			tmp_record(cSamples, nSamples, agcGain);		// save radio sound
 		for (i = 0; i < nSamples; i++)
-			cSamples[i] *= agc_level;
+			cSamples[i] *= agc_level;		// apply AGC
+		if (quisk_record_state == PLAYBACK)
+			tmp_playback(cSamples, nSamples, audioVolume);	// replace radio sound
 	}
 	return nSamples;
 }
@@ -849,6 +1087,15 @@ static PyObject * get_state(PyObject * self, PyObject * args)
 		);
 }
 
+static PyObject * get_squelch(PyObject * self, PyObject * args)
+{
+	int freq;
+
+	if (!PyArg_ParseTuple (args, "i", &freq))
+		return NULL;
+	return PyInt_FromLong(IsSquelch(freq));
+}
+
 static PyObject * get_overrange(PyObject * self, PyObject * args)
 {
 	if (!PyArg_ParseTuple (args, ""))
@@ -858,28 +1105,43 @@ static PyObject * get_overrange(PyObject * self, PyObject * args)
 
 static PyObject * get_filter_rate(PyObject * self, PyObject * args)
 {  // return the filter sample rate as used by quisk_process_samples
-	int rate;
+	int filter_srate;
 
 	if (!PyArg_ParseTuple (args, ""))
 		return NULL;
-	rate = 24000;
+
+	switch((quisk_sound_state.sample_rate + 100) / 1000) {
+	case 53:	// SDR-IQ
+		filter_srate = quisk_sound_state.sample_rate;
+		break;
+	case 111:	// SDR-IQ
+		filter_srate = quisk_sound_state.sample_rate / 2;
+		break;
+	case 133:	// SDR-IQ
+		filter_srate = quisk_sound_state.sample_rate / 2;
+		break;
+	case 185:	// SDR-IQ
+		filter_srate = quisk_sound_state.sample_rate / 3;
+		break;
+	default:
+		filter_srate = 48000;
+		break;
+	}
 	switch(rxMode) {
 	case 0:
-	case 1:
-		rate /= 4;	  // CW
+	case 1:			// CW
+		filter_srate /= 8;
 		break;
 	case 2:
-	case 3:
-	case 7:
-	default:
-		rate /= 2;	  // SSB
+	case 3:			// SSB
+		filter_srate /= 4;
+		break;
+	case 4:			// AM
+	case 5:			// FM
+		filter_srate /= 2;
 		break;
-	case 4:
-		break;		  // AM
-	case 5:
-		break;		  // FM
 	}
-	return PyInt_FromLong(rate);
+	return PyInt_FromLong(filter_srate);
 }
 
 static PyObject * get_smeter(PyObject * self, PyObject * args)
@@ -889,6 +1151,17 @@ static PyObject * get_smeter(PyObject * self, PyObject * args)
 	return PyFloat_FromDouble(Smeter);
 }
 
+static PyObject * measure_frequency(PyObject * self, PyObject * args)
+{
+	int mode;
+
+	if (!PyArg_ParseTuple (args, "i", &mode))
+		return NULL;
+	if (mode >= 0)	// mode >= 0 set the mode; mode < 0, just return the frequency
+		measure_freq_mode = mode;
+	return PyFloat_FromDouble(measured_frequency);
+}
+
 static PyObject * add_tone(PyObject * self, PyObject * args)
 {  /* Add a test tone to the captured audio data */
 	int freq;
@@ -1144,7 +1417,7 @@ int quisk_read_rx_udp(complex * samp)	// Read samples from UDP
 			dc_count = 0;
 			//printf("dc average %lf   %lf %d\n", creal(dc_average), cimag(dc_average), dc_count);
 			//printf("dc polar %.0lf   %d\n", cabs(dc_average),
-               		//	(int)(360.0 / 2 / M_PI * atan2(cimag(dc_average), creal(dc_average))));
+			   		//	(int)(360.0 / 2 / M_PI * atan2(cimag(dc_average), creal(dc_average))));
 		}
 	}
 	if (use_remove_dc)
@@ -1349,6 +1622,14 @@ static PyObject * set_sidetone(PyObject * self, PyObject * args)
 	return Py_None;
 }
 
+static PyObject * set_squelch(PyObject * self, PyObject * args)
+{  /* Change the squelch parameter */
+	if (!PyArg_ParseTuple (args, "d", &squelch_level))
+		return NULL;
+	Py_INCREF (Py_None);
+	return Py_None;
+}
+
 static PyObject * set_volume(PyObject * self, PyObject * args)
 {
 	if (!PyArg_ParseTuple (args, "d", &audioVolume))
@@ -1417,10 +1698,12 @@ static PyObject * get_graph(PyObject * self, PyObject * args)
 	case 1:		// CWU
 	case 4:		// AM
 	case 5:		// FM
+	case 9:		// DGT-IQ
 	default:
 		i = (int)((double)quisk_tx_tune_freq * fft_size / sample_rate - d2 / 2 + 0.5);
 		break;
 	case 2:		// LSB:  bandwidth is below tx frequency
+	case 8:
 		i = (int)((double)quisk_tx_tune_freq * fft_size / sample_rate - d2 + 0.5);
 		break;
 	case 3:		// USB:  bandwidth is above tx frequency
@@ -1429,20 +1712,17 @@ static PyObject * get_graph(PyObject * self, PyObject * args)
 		break;
 	}
 	if (i > - fft_size / 2 && i + n + 1 < fft_size / 2) {	// too close to edge?
-		scale = 1.0 / 2147483647.0 / fft_size;
 		for (j = 0; j < n; i++, j++) {
 			if (i < 0)
 				c = ptFft->samples[fft_size + i];	// negative frequencies
 			else
 				c = ptFft->samples[i];				// positive frequencies
-			c *= scale;					// scale to correct amplitude
 			meter += c * conj(c);		// add square of amplitude
 		}
 		if (i < 0)			// add fractional next bin
 			c = ptFft->samples[fft_size + i];
 		else
 			c = ptFft->samples[i];
-		c *= scale;
 		meter += c * conj(c) * (d2 - n);	// fractional part of next bin
 	}
 	// Average the fft data into the graph in order of frequency
@@ -1471,22 +1751,28 @@ static PyObject * get_graph(PyObject * self, PyObject * args)
 				d2 += fft_avg[k];
 		fft_avg[i] = d2;
 	}
-	Smeter = meter / average_count;		// record the new s-meter value
+	scale = 1.0 / 2147483647.0 / fft_size;
+	Smeter = meter * scale * scale / average_count;		// record the new s-meter value
 	meter = 0;
 	if (Smeter > 0)
 		Smeter = 10.0 * log10(Smeter);
 	else
 		Smeter = -140.0;
-	Smeter += 4.25969;		// Origin of this correction is unknown
+	// This correction is for a -40 dB strong signal, and is caused by FFT leakage
+	// into adjacent bins. It is the amplitude that is spread out, not the squared amplitude.
+	Smeter += 4.25969;
 	count_fft = 0;
 	tuple2 = PyTuple_New(data_width);
-	scale = 1.0 / average_count / fft_size;	// Divide by sample count
-	scale /= pow(2.0, 31);			// Normalize to max == 1
-	for (i = 0, k = 0; k < data_width; k++, i++) {
-		d2 = log10(fft_avg[k] * scale);
-		if (d2 < -10)
-			d2 = -10;
-		PyTuple_SetItem(tuple2, i, PyFloat_FromDouble(20.0 * d2));
+	// scale = 1.0 / average_count / fft_size;	// Divide by sample count
+	// scale /= pow(2.0, 31);			// Normalize to max == 1
+	scale = log10(average_count) + log10(fft_size) + 31.0 * log10(2.0);
+	scale *= 20.0;
+	for (i = 0; i < data_width; i++) {
+		d2 = 20.0 * log10(fft_avg[i]) - scale;
+		if (d2 < -200)
+			d2 = -200;
+		current_graph[i] = d2;
+		PyTuple_SetItem(tuple2, i, PyFloat_FromDouble(d2));
 	}
 	for (i = 0; i < fft_size; i++)
 		fft_avg[i] = 0;
@@ -1586,6 +1872,77 @@ static PyObject * get_filter(PyObject * self, PyObject * args)
 	return tuple2;
 }
 
+static void measure_freq(complex * cSamples, int nSamples, int srate)
+{
+	int i, k, center, ipeak;
+	double dmax, c3, freq;
+	complex cBuffer[SAMP_BUFFER_SIZE];
+	static int index = 0;				// current index of samples
+	static int fft_size=12000;			// size of fft data
+	static int fft_count=0;				// number of ffts for the average
+	static fftw_complex * samples;		// complex data for fft
+	static fftw_plan planA;				// fft plan for fft
+	static double * fft_window;			// window function
+	static double * fft_average;		// average amplitudes
+	static struct quisk_cHB45Filter HalfBand1 = {NULL, 0, 0};
+	static struct quisk_cHB45Filter HalfBand2 = {NULL, 0, 0};
+	static struct quisk_cHB45Filter HalfBand3 = {NULL, 0, 0};
+
+	if ( ! cSamples) {		// malloc new space and initialize
+		samples = (fftw_complex *) fftw_malloc(sizeof(fftw_complex) * fft_size);
+		planA = fftw_plan_dft_1d(fft_size, samples, samples, FFTW_FORWARD, FFTW_MEASURE);
+		fft_window = (double *) malloc(sizeof(double) * (fft_size + 1));
+		fft_average = (double *) malloc(sizeof(double) * fft_size);
+		memset(fft_average, 0, sizeof(double) * fft_size);
+		for (i = 0; i < fft_size; i++)	// Hanning
+			fft_window[i] = 0.50 - 0.50 * cos(2. * M_PI * i / (fft_size - 1));
+		return;
+	}
+	memcpy(cBuffer, cSamples, nSamples * sizeof(complex));	// do not destroy cSamples
+	nSamples = quisk_cDecim2HB45(cBuffer, nSamples, &HalfBand1);
+	nSamples = quisk_cDecim2HB45(cBuffer, nSamples, &HalfBand2);
+	nSamples = quisk_cDecim2HB45(cBuffer, nSamples, &HalfBand3);
+	srate /= 8;		// sample rate as decimated
+	for (i = 0; i < nSamples && index < fft_size; i++, index++)
+		samples[index] = cBuffer[i];
+	if (index < fft_size)
+		return;		// wait for a full array of samples
+	for (i = 0; i < fft_size; i++)	// multiply by window
+		samples[i] *= fft_window[i];
+	fftw_execute(planA);		// Calculate FFT
+	index = 0;
+	fft_count++;
+	// Average the fft data into the graph in order of frequency
+	k = 0;
+	for (i = fft_size / 2; i < fft_size; i++)			// Negative frequencies
+		fft_average[k++] += cabs(samples[i]);
+	for (i = 0; i < fft_size / 2; i++)					// Positive frequencies
+		fft_average[k++] += cabs(samples[i]);
+	if (fft_count < measure_freq_mode / 2)
+		return;		// continue with average
+	// time for a calculation
+	fft_count = 0;
+	dmax = 1.e-20;
+	ipeak = 0;
+	center = fft_size / 2 - rit_freq * fft_size / srate;
+	k = 500;	// desired +/- half-bandwidth to search for a peak
+	k = k * fft_size / srate;		// convert to index
+	for (i = center - k; i <= center + k; i++) {	// search for a peak near the RX freq
+		if (fft_average[i] > dmax) {
+			dmax = fft_average[i];
+			ipeak = i;
+		}
+	}
+	c3 = 1.36 * (fft_average[ipeak+1] - fft_average[ipeak - 1]) / (fft_average[ipeak-1] + fft_average[ipeak] + fft_average[ipeak+1]);
+	freq = srate * (2 * (ipeak + c3) - fft_size) / 2 / fft_size;
+	freq += rx_tune_freq;
+	// printf("\n%5d %.4lf %.2lf k=%d\n", ipeak, c3, freq, k);
+	measured_frequency = freq;
+	//for (i = ipeak - 10; i <= ipeak + 10 && i >= 0 && i < fft_size; i++)
+	//	printf("%4d %12.5f\n", i, fft_average[i] / dmax);
+	memset(fft_average, 0, sizeof(double) * fft_size);
+}
+
 static PyObject * Xdft(PyObject * pyseq, int inverse, int window)
 {  // Native spectral order is 0 Hz to (Fs - 1).  Change this to
    // - (Fs - 1)/2 to + Fs/2.  For even Fs==32, there are 15 negative
@@ -1619,9 +1976,8 @@ static PyObject * Xdft(PyObject * pyseq, int inverse, int window)
 		planF = fftw_plan_dft_1d(fft_size, samples, samples, FFTW_FORWARD, FFTW_MEASURE);
 		planB = fftw_plan_dft_1d(fft_size, samples, samples, FFTW_BACKWARD, FFTW_MEASURE);
 		fft_window = (double *) malloc(sizeof(double) * (fft_size + 1));
-		//for (i = 0, j = -fft_size / 2; i < fft_size; i++, j++) {
 		for (i = 0; i <= size/2; i++) {
-			if (1)    // Blackman window
+			if (1)	// Blackman window
 				fft_window[i] = fft_window[size - i] = 0.42 + 0.50 * cos(2. * M_PI * i / size) + 
 					0.08 * cos(4. * M_PI * i / size);
 			else if (1)	// Hamming
@@ -1784,6 +2140,10 @@ static PyObject * record_app(PyObject * self, PyObject * args)
 		else	// Hanning
 			fft_window[i] = 0.5 + 0.5 * cos(2. * M_PI * j / fft_size);
 	}
+	if (current_graph)
+		free(current_graph);
+	current_graph = (double *) malloc(sizeof(double) * data_width);
+	measure_freq(NULL, 0, 0);
 #if DEBUG_IO
 	QuiskPrintTime(NULL, 0);
 #endif
@@ -1842,6 +2202,7 @@ static PyMethodDef QuiskMethods[] = {
 	{"get_filter", get_filter, METH_VARARGS, "Return the frequency response of the receive filter."},
 	{"get_filter_rate", get_filter_rate, METH_VARARGS, "Return the sample rate used for the filters."},
 	{"get_tx_filter", quisk_get_tx_filter, METH_VARARGS, "Return the frequency response of the transmit filter."},
+	{"measure_frequency", measure_frequency, METH_VARARGS, "Set the method, return the measured frequency."},
 	{"get_overrange", get_overrange, METH_VARARGS, "Return the count of overrange (clip) for the ADC."},
 	{"get_smeter", get_smeter, METH_VARARGS, "Return the S meter reading."},
 	{"invert_spectrum", invert_spectrum, METH_VARARGS, "Invert the input RF spectrum"},
@@ -1849,8 +2210,12 @@ static PyMethodDef QuiskMethods[] = {
 	{"record_graph", record_graph, METH_VARARGS, "Record graph parameters."},
 	{"set_ampl_phase", quisk_set_ampl_phase, METH_VARARGS, "Set the sound card amplitude and phase corrections."},
 	{"set_agc", set_agc, METH_VARARGS, "Set the AGC parameters."},
+	{"set_squelch", set_squelch, METH_VARARGS, "Set the squelch parameter."},
+	{"get_squelch", get_squelch, METH_VARARGS, "Get the squelch state, 0 or 1."},
+	{"set_file_record", quisk_set_file_record, METH_VARARGS, "Set the state and names of the recording files."},
 	{"set_filters", set_filters, METH_VARARGS, "Set the receive audio I and Q channel filters."},
 	{"set_noise_blanker", set_noise_blanker, METH_VARARGS, "Set the noise blanker level."},
+	{"set_record_state", set_record_state, METH_VARARGS, "Set the temp buffer record and playback state."},
 	{"set_rx_mode", set_rx_mode, METH_VARARGS, "Set the receive mode: CWL, USB, AM, etc."},
 	{"set_spot_level", quisk_set_spot_level, METH_VARARGS, "Set the spot mode: 0, 1, ... or -1 for no spot"},
 	{"set_sidetone", set_sidetone, METH_VARARGS, "Set the sidetone volume and frequency."},
