@@ -4,6 +4,7 @@
 // Sound parameters
 //
 #define QUISK_SC_SIZE		128
+#define QUISK_PATH_SIZE     256         // max file path length
 #define IP_SIZE				32
 #define MAX_FILTER_SIZE		10001
 #define BIG_VOLUME			2.2e9
@@ -89,6 +90,12 @@ struct sound_conf {
 	double mic_out_volume;
 } ;
 
+enum quisk_rec_state {
+	IDLE,
+	RECORD,
+	PLAYBACK } ;
+extern enum quisk_rec_state quisk_record_state;
+
 extern struct sound_conf quisk_sound_state, * pt_quisk_sound_state;
 extern int mic_max_display;		// display value of maximum microphone signal level
 extern int data_width;
@@ -111,6 +118,7 @@ extern PyObject * quisk_play_channels(PyObject * , PyObject *);
 extern PyObject * quisk_micplay_channels(PyObject * , PyObject *);
 extern PyObject * quisk_sound_devices(PyObject * , PyObject *);
 extern PyObject * quisk_sound_errors(PyObject *, PyObject *);
+extern PyObject * quisk_set_file_record(PyObject *, PyObject *);
 
 // These function pointers are the Start/Stop/Read interface for
 // the SDR-IQ and any other C-language extension modules that return
@@ -139,6 +147,7 @@ int quisk_read_rx_udp(complex *);
 void quisk_set_tx_mode(void);
 void ptimer(int);
 int quisk_extern_demod(complex *, int, double);
+void quisk_tmp_microphone(complex *, int);
 
 int  quisk_read_alsa(struct sound_dev *, complex *);
 void quisk_play_alsa(struct sound_dev *, int, complex *, int);
