@@ -74,6 +74,11 @@ filter_y_zero  = 0
 #persistent_state = False
 persistent_state = True
 
+# The quisk config screen has a "favorites" tab where you can enter the frequencies and modes of
+# stations.  The data is stored in this file; default quisk_favorites.txt in the directory
+# where your config file is located.
+favorites_file_path = ''
+
 # This converts from dB to S-units for the S-meter (it is in S-units).
 correct_smeter = 15.5
 
@@ -81,20 +86,55 @@ correct_smeter = 15.5
 # the passband edges are not valid.  Use 0.85 for the SDR-IQ.
 display_fraction = 1.00
 
+# Quisk has record and playback buttons to save radio sound.  If there is no more room for
+# sound, the old sound is discarded and the most recent sound is retained.  This controls
+# the maximum length of sound storage in minutes.  If you want to transmit recorded sound,
+# then mic_sample_rate must equal playback_rate and both must be 48000.
+max_record_minutes = 0.25
+
+# Thanks to Steve Murphy, KB8RWQ for the patch adding additional color control.
 # Define colors used by all widgets in wxPython colour format:
-color_bg		= 'light steel blue'	# Lower screen background
-color_graph		= 'lemonchiffon1'		# Graph background
-color_gl		= 'grey'				# Lines on the graph
-color_btn		= 'steelblue2'			# button color
-color_check_btn	= 'yellow2'				# color of a check button when it is checked
-color_cycle_btn	= 'goldenrod3'			# color of a cycle button when it is checked
-color_adjust_btn	= 'orange3'			# color of an adjustable button when it is checked
-color_test		= 'hot pink'			# color of a button used for test (turn off for tx)
-color_freq		= 'lightcyan1'			# background color of frequency and s-meter
-color_entry		= color_freq			# frequency entry box
-color_disable	= 'white'				# text color for a disabled button
-color_bandwidth = 'lemonchiffon2'		# color for bandwidth display; thanks to WB4JFI
+color_bg			= 'light steel blue'	# Lower screen background
+color_graph			= 'lemonchiffon1'		# Graph background
+color_config2		= 'lemonchiffon3'		# color in tab row of config screen
+color_gl			= 'grey'				# Lines on the graph
+color_graphticks	= 'black'				# Graph ticks
+color_graphline		= '#005500'				# graph data line color
+color_graphlabels	= '#555555'				# graph label color
+color_btn			= 'steelblue2'			# button color
+color_check_btn		= 'yellow2'				# color of a check button when it is checked
+color_cycle_btn		= 'goldenrod3'			# color of a cycle button when it is checked
+color_adjust_btn	= 'orange3'				# color of an adjustable button when it is checked
+color_test			= 'hot pink'			# color of a button used for test (turn off for tx)
+color_freq			= 'lightcyan1'			# background color of frequency and s-meter
+color_entry			= color_freq			# frequency entry box
+color_enable		= 'black'				# text color for an enabled button
+color_disable		= 'white'				# text color for a disabled button
+color_bandwidth		= 'lemonchiffon2'		# color for bandwidth display; thanks to WB4JFI
 #color_bandwidth = 'lemonchiffon3'
+color_txline		= 'red'					# vertical line color for tx in graph
+color_rxline		= 'green'				# vertical line color for rx in graph
+
+# This is a dark color scheme designed by Steve Murphy, KB8RWQ.
+#color_bg                = '#111111'
+#color_graph             = '#111111'
+#color_config2           = color_bg
+#color_gl                = '#555555'
+#color_graphticks        = '#DDDDDD'
+#color_graphline         = '#00AA00'
+#color_graphlabels       = '#FFFFFF'
+#color_btn               = '#666666'
+#color_check_btn         = '#996699'
+#color_cycle_btn         = '#666699'
+#color_adjust_btn        = '#669999'
+#color_test              = 'hot pink'
+#color_freq              = '#333333'
+#color_entry             = color_freq
+#color_enable            = 'white'
+#color_disable           = 'black'
+#color_bandwidth         = '#333333'
+#color_txline            = 'red'
+#color_rxline            = 'green'
 
 filter_display = 1	# Display the filter bandwidth on the graph screen; 0 or 1; thanks to WB4JFI
 
@@ -183,7 +223,7 @@ rx_ip = ""							# Receiver IP address for VFO control
 # see the sample config file in the hiqsdr package directory, and set these:
 # tx_level sets the transmit level 0 to 255 for each band.  The None band is the default.
 tx_level = {None:120, '60':110}
-# Mode DGTL uses this instead of tx_level, so you can reduce the power.
+# Digital modes use this instead of tx_level, so you can reduce the power.
 digital_tx_level = 20
 # If you use the HiQSDR hardware, set these:
 # The HiQSDR_BandDict sets the preselect (4 bits) on the X1 connector.
@@ -208,6 +248,7 @@ si570_xtal_freq = 114285000
 # be 48 kHz for the SDR-IQ and UDP port samples, and sample_rate for sound
 # card capture.  Set it yourself for other rates or hardware.
 # The playback_rate must be 24000, 48000, 96000 or 192000.
+# The preferred rate is 48000 for use with digital modes and transmit of recorded audio.
 # playback_rate = 48000
 
 # If you use quisk_hardware_fixed.py, this is the fixed VFO frequency in Hertz
@@ -222,28 +263,42 @@ key_poll_msec = 0
 # custom hardware file with a custom ChangeFrequency() method too.
 mouse_tune_method = 0	# The Quisk tune frequency changes and the VFO frequency is unchanged.
 #mouse_tune_method = 1	# The Quisk tune frequency is unchanged and the VFO changes.
+# configurable mouse wheel thanks to DG7MGY
+mouse_wheelmod = 50		# Round frequency when using mouse wheel (50 Hz)
+
+# If freq_spacing is not zero, frequencies are rounded to the freq_base plus the
+# freq_spacing; frequency = freq_base + N * freq_spacing.  This is useful at
+# VHF and higher when Quisk is used with a transverter.
+freq_spacing = 0
+freq_base = 0
 
 # This is the CW tone frequency in Hertz
 cwTone = 600
 
-# The "DGTL" mode mostly acts like USB, but it sends received audio to an external
-# program that can decode digital modes, and receives audio to transmit.
-# The only program currently supported is Fldigi.  Set Fldigi to USB, XML-RPC control.
+# These options are used by the digital modes that send audio to an external
+# program, and receive audio to transmit.
+# Set Fldigi to USB, XML-RPC control.
 digital_xmlrpc_url = "http://localhost:7362"	# URL for control by XML-RPC
-# Input audio from an external program for use with mode DGTL.  The input must be
-# stereo at 48000 sps.
+# Input audio from an external program for use with digital modes.  The input must be
+# stereo at 48000 sps, and you must set mic_sample_rate to 48000 also.
 digital_input_name = ""		# device name for transmit audio
 # digital_input_name = 'hw:Loopback,0'
-# Output audio to an external program for use with mode DGTL.  The output is
+# Output audio to an external program for use with digital modes.  The output is
 # stereo at the same sample rate as the radio sound playback.
 digital_output_name = ""	# device name for received audio
 # digital_output_name = digital_input_name
 
+# You can control Quisk from Hamlib.  Set the Hamlib rig to 2 and the device for rig 2 to
+# localhost:4575, or other hamlib_port as used by Quisk.
+hamlib_port = 4575		# Standard port for Quisk control.  Set the port in Hamlib to 4575 too.
+#hamlib_port = 4532		# Default port for rig 2.  Use this if you can not set the Hamlib port.
+#hamlib_port = 0		# Turn off Hamlib control.
+
 # If you use the microphone feature, the mic_channel_I and Q are the two capture
 # microphone channels.  Quisk uses a monophonic mic, so audio is taken from the I
 # channel, and the Q channel is (currently) ignored.  It is OK to set the same
-# channel number for both, and this is necessary for a USB mono mic.  If you
-# change the sample rate, you will need to change the C code to use different filters.
+# channel number for both, and this is necessary for a USB mono mic.  The mic sample rate
+# should be 48000 to enable digital modes and the sound recorder to work, but 8000 can be used.
 # Mic samples can be sent to an Ethernet device (use tx_ip and name_of_mic_play = "")
 # or to a sound card (use name_of_mic_play="hw:1" or other device).
 # If mic samples are sent to a sound card for Tx, the samples are tuned to the audio
@@ -253,7 +308,7 @@ digital_output_name = ""	# device name for received audio
 
 # Microphone capture:
 microphone_name = ""		# Name of microphone capture device (or "hw:1")
-mic_sample_rate = 48000		# Microphone capture sample rate in Hertz, must be 48000 or 8000
+mic_sample_rate = 48000		# Microphone capture sample rate in Hertz, should be 48000, can be 8000
 mic_channel_I = 0		# Soundcard index of mic capture audio channel
 mic_channel_Q = 0		# Soundcard index of ignored capture channel
 # Microphone samples sent to soundcard:
@@ -305,6 +360,7 @@ FilterBwSSB	= (2000, 2200, 2500, 2800, 3000, 3300)
 FilterBwAM	= (4000, 5000, 6000, 8000, 10000, 9000)
 FilterBwFM	= (8000, 10000, 12000, 15000, 17000, 20000)
 FilterBwIMD	= FilterBwSSB
+FilterBwDGT= (1600, 3200, 4800, 10000, 20000, 20000)
 FilterBwEXT	= (8000, 10000, 12000, 15000, 17000, 20000)
 
 # This is the data used to draw colored lines on the frequency X axis to
@@ -324,13 +380,23 @@ AM		= '#00FF00'
 Packet	= '#00FFFF'
 Beacons	= '#66FF66'
 Satellite	= '#22AA88'
-Repeater	= '#AA00FF'
+Repeater	= '#AA00FF'	# Repeater outputs
+RepInput	= '#AA88FF'	# Repeater inputs
 Simplex	= '#00FF44'
+Special	= 'hot pink'
 Other	= '#888888'
 
 # Colors start at the indicated frequency and continue until the
 # next frequency.  The special color "None" turns off color.
+#
+# To change BandPlan in your config file, first remove any frequencies in the range
+# you want to change; then add your frequencies; and then sort the list.  Or you could just
+# replace the whole list.
 BandPlan = [
+  # Test display of colors
+  #[      0, CW], [  50000, eCW], [ 100000, Phone], [ 150000, ePhone], [ 200000, Data], [ 250000, DxData], [ 300000, RTTY], [ 350000, SSTV],
+  #[ 400000, AM], [ 450000, Packet], [ 500000, Beacons], [ 550000, Satellite], [ 600000, Repeater], [ 650000, RepInput], [ 700000, Simplex],
+  #[ 750000, Other], [ 800000, Special], [ 850000, None],
   # 160 meters
   [ 1800000, Data],
   [ 1809000, Other],
@@ -439,6 +505,53 @@ BandPlan = [
   [50000000, Beacons],
   [50100000, Phone],
   [54000000, None],
+  # 2 meters
+  [144000000, CW],
+  [144200000, Phone],
+  [144275000, Beacons],
+  [144300000, Satellite],
+  [144380000, Special],
+  [144400000, Satellite],
+  [144500000, RepInput],
+  [144900000, Other],
+  [145100000, Repeater],
+  [145500000, Other],
+  [145800000, Satellite],
+  [146010000, RepInput],
+  [146400000, Simplex],
+  [146510000, Special],     # Simplex calling frequency
+  [146530000, Simplex],
+  [146610000, Repeater],
+  [147420000, Simplex],
+  [147600000, RepInput],
+  [148000000, None],
+  # 1.25 meters
+  [222000000, Phone],
+  [222250000, RepInput],
+  [223400000, Simplex],
+  [223520000, Data],
+  [223640000, Repeater],
+  [225000000, None],
+  #70 centimeters
+  [420000000, SSTV],
+  [432000000, Satellite],
+  [432070000, Phone],
+  [432300000, Beacons],
+  [432400000, Phone],
+  [433000000, Repeater],
+  [435000000, Satellite],
+  [438000000, Repeater],
+  [445900000, Simplex],
+  [445990000, Special],     # Simplex calling frequency
+  [446010000, Simplex],
+  [446100000, Repeater],
+  [450000000, None],
+  # 33 centimeters
+  [902000000, Other],
+  [928000000, None],
+  # 23 centimeters
+  [1240000000, Other],
+  [1300000000, None],
   ]
 
 # For each band, this dictionary gives the lower and upper band edges.  Frequencies
@@ -450,6 +563,7 @@ BandEdge = {
 	'17' :(18068000, 18168000), '15' :(21000000, 21450000),
 	'12' :(24890000, 24990000),	'10' :(28000000, 29700000),
 	'6'  :(50000000, 54000000),
+	'2'  :(144000000, 148000000),
 	}
 
 # For each band, this dictionary gives the initial center frequency, tuning
