@@ -24,6 +24,7 @@ class FrequencyDisplay(wx.lib.stattext.GenStaticText):
     border = self.border = (height - self.height) / 2
     self.height_and_border = h + border * 2
     self.SetBackgroundColour(conf.color_freq)
+    self.SetForegroundColour(conf.color_enable)
     gbs.Add(self, (0, 0), (1, 3),
        flag=wx.EXPAND | wx.TOP | wx.BOTTOM, border=border)
   def Clip(self, clip):
@@ -187,7 +188,7 @@ class QuiskButtons:
   def DrawLabel(self, dc, width, height, dx=0, dy=0):	# Override to change Disable text color
       dc.SetFont(self.GetFont())
       if self.IsEnabled():
-          dc.SetTextForeground(self.GetForegroundColour())
+          dc.SetTextForeground(conf.color_enable)
       else:
           dc.SetTextForeground(conf.color_disable)
           #dc.SetTextForeground(wx.SystemSettings.GetColour(wx.SYS_COLOUR_GRAYTEXT))
@@ -279,7 +280,7 @@ class QuiskRepeatbutton(QuiskButtons, wx.lib.buttons.GenButton):
 class QuiskCheckbutton(QuiskButtons, wx.lib.buttons.GenToggleButton):
   """A button that pops up and down, and changes color with each push."""
   # Check button; get the checked state with self.GetValue()
-  def __init__(self, parent, command, text, color=None):
+  def __init__(self, parent, command, text, color=None, use_right=False):
     wx.lib.buttons.GenToggleButton.__init__(self, parent, -1, text)
     self.InitButtons(text)
     self.Bind(wx.EVT_BUTTON, self.OnButton)
@@ -289,6 +290,10 @@ class QuiskCheckbutton(QuiskButtons, wx.lib.buttons.GenToggleButton):
       self.color = conf.color_check_btn
     else:
       self.color = color
+    self.direction = 1
+    if use_right:
+      self.Bind(wx.EVT_RIGHT_DOWN, self.OnRightDown)
+      self.Bind(wx.EVT_RIGHT_UP, self.OnRightUp)
   def SetValue(self, value, do_cmd=False):
     wx.lib.buttons.GenToggleButton.SetValue(self, value)
     self.button_down = value
@@ -307,6 +312,12 @@ class QuiskCheckbutton(QuiskButtons, wx.lib.buttons.GenToggleButton):
       self.SetBackgroundColour(conf.color_btn)
     if self.command:
       self.command(event)
+  def OnRightDown(self, event):
+    self.direction = -1
+    self.OnLeftDown(event) 
+  def OnRightUp(self, event):
+    self.OnLeftUp(event)
+    self.direction = 1
 
 class QFilterButtonWindow(wx.Frame):
   """Create a window with controls for the button"""
@@ -432,10 +443,11 @@ class QuiskSliderButton(QuiskCheckbutton):
       self.adjust = None
     else:
       self.adjust = QSliderButtonWindow(self)
-    self.SetLabel()
   def SetLabel(self, text=None):
     if text is not None:
       QuiskCheckbutton.SetLabel(self, text)
+  def SetSlider(self, value):
+    self.slider_value = value
 
 class QuiskSpotButton(QuiskSliderButton):
   def SetLabel(self, text=None):
