@@ -36,6 +36,12 @@ static struct sound_dev * PlaybackDevices[] = {&Playback, &MicPlayback, &Digital
 
 struct sound_conf quisk_sound_state;	// Current sound status
 
+static char file_name_audio[QUISK_PATH_SIZE];   // file name for recording speaker output
+static char file_name_samples[QUISK_PATH_SIZE];	// file name for recording samples
+static int is_recording_audio;
+static int is_recording_samples;
+static int want_record;
+
 static ty_sample_start pt_sample_start;
 static ty_sample_stop  pt_sample_stop;
 static ty_sample_read  pt_sample_read;
@@ -105,6 +111,162 @@ static void correct_sample (struct sound_dev * dev, complex * cSamples, int nSam
 	}
 }
 
+static int record_audio(complex * cSamples, int nSamples)
+{  // Record the speaker audio to a WAV file, PCM, 16 bits, one channel
+	static FILE * fp = NULL;	// TODO: correct for big-endian byte order
+	static unsigned int samples=0, remain=0;
+	int j;
+	short samp;			// must be 2 bytes
+	unsigned int u;		// must be 4 bytes
+	unsigned short s;	// must be 2 bytes
+
+	switch (nSamples) {
+	case -1:			// Open the file
+		fp = fopen(file_name_audio, "wb");
+		if ( ! fp)
+			return 0;
+		if (fwrite("RIFF", 1, 4, fp) != 4) {
+			fclose(fp);
+			fp = NULL;
+			return 0;
+		}
+		// pcm data, 16-bit samples, one channel
+		u = 36;
+		fwrite(&u, 4, 1, fp);
+		fwrite("WAVE", 1, 4, fp);
+		fwrite("fmt ", 1, 4, fp);
+		u = 16;
+		fwrite(&u, 4, 1, fp);
+		s = 1;		// wave_format_pcm
+		fwrite(&s, 2, 1, fp);
+		s = 1;		// number of channels
+		fwrite(&s, 2, 1, fp);
+		u = Playback.sample_rate;	// sample rate
+		fwrite(&u, 4, 1, fp);
+		u *= 2;
+		fwrite(&u, 4, 1, fp);
+		s = 2; 
+		fwrite(&s, 2, 1, fp);
+		s = 16; 
+		fwrite(&s, 2, 1, fp);
+		fwrite("data", 1, 4, fp);
+		u = 0;
+		fwrite(&u, 4, 1, fp);
+		samples = 0;
+		remain = 2147483000;
+		break;
+	case -2:		// close the file
+		if (fp)
+			fclose(fp);
+		fp = NULL;
+		remain = 0;
+		break;
+	default:		// write the sound data to the file
+		u = (unsigned int)nSamples;
+		if (u >= remain)
+			return 0;
+		samples += u;
+		remain -= u;
+		fseek(fp, 40, SEEK_SET);	// seek from the beginning
+		u = 2 * samples;
+		fwrite(&u, 4, 1, fp);
+		fseek(fp, 4, SEEK_SET);		// seek from the beginning
+		u += 36;
+		fwrite(&u, 4, 1, fp);
+		fseek(fp, 0, SEEK_END);		// seek to the end
+		for (j = 0; j < nSamples; j++) {
+			samp = (short)(creal(cSamples[j]) / 65536.0);
+			fwrite(&samp, 2, 1, fp);
+		}
+		break;
+	}
+	return 1;
+}
+
+static int record_samples(complex * cSamples, int nSamples)
+{  // Record the samples to a WAV file, two float samples I/Q
+	static FILE * fp = NULL;	// TODO: correct for big-endian byte order
+	static unsigned int samples=0, remain=0;
+	int j;
+	float samp;			// must be 4 bytes
+	unsigned int u;		// must be 4 bytes
+	unsigned short s;	// must be 2 bytes
+
+	switch (nSamples) {
+	case -1:			// Open the file
+		fp = fopen(file_name_samples, "wb");
+		if ( ! fp)
+			return 0;
+		if (fwrite("RIFF", 1, 4, fp) != 4) {
+			fclose(fp);
+			fp = NULL;
+			return 0;
+		}
+		// IEEE float data, two channels
+		u = 50;
+		fwrite(&u, 4, 1, fp);
+		fwrite("WAVE", 1, 4, fp);
+		fwrite("fmt ", 1, 4, fp);
+		u = 18;
+		fwrite(&u, 4, 1, fp);
+		s = 3;		// wave_format_ieee_float
+		fwrite(&s, 2, 1, fp);
+		s = 2;		// number of channels
+		fwrite(&s, 2, 1, fp);
+		u = quisk_sound_state.sample_rate;	// sample rate
+		fwrite(&u, 4, 1, fp);
+		u *= 8;
+		fwrite(&u, 4, 1, fp);
+		s = 8; 
+		fwrite(&s, 2, 1, fp);
+		s = 32; 
+		fwrite(&s, 2, 1, fp);
+		s = 0; 
+		fwrite(&s, 2, 1, fp);
+		fwrite("fact", 1, 4, fp);
+		u = 4;
+		fwrite(&u, 4, 1, fp);
+		u = 0;
+		fwrite(&u, 4, 1, fp);
+		fwrite("data", 1, 4, fp);
+		u = 0;
+		fwrite(&u, 4, 1, fp);
+		samples = 0;
+		remain = 536870000;
+		break;
+	case -2:	// close the file
+		if (fp)
+			fclose(fp);
+		fp = NULL;
+		remain = 0;
+		break;
+	default:	// write the sound data to the file
+		u = (unsigned int)nSamples;
+		if (u >= remain)
+			return 0;
+		samples += u;
+		remain -= u;
+		fseek(fp, 54, SEEK_SET);	// seek from the beginning
+		u = 8 * samples;
+		fwrite(&u, 4, 1, fp);
+		fseek(fp, 4, SEEK_SET);		// seek from the beginning
+		u += 50 ;
+		fwrite(&u, 4, 1, fp);
+		fseek(fp, 46, SEEK_SET);	// seek from the beginning
+		u = samples * 2;
+		fwrite(&u, 4, 1, fp);
+		fseek(fp, 0, SEEK_END);		// seek to the end
+		for (j = 0; j < nSamples; j++) {
+			samp = creal(cSamples[j]) / CLIP32;
+			fwrite(&samp, 4, 1, fp);
+			samp = cimag(cSamples[j]) / CLIP32;
+			fwrite(&samp, 4, 1, fp);
+		}
+		break;
+	}
+	return 1;
+}
+
 void quisk_sample_source(ty_sample_start start, ty_sample_stop stop, ty_sample_read read)
 {
 	pt_sample_start = start;
@@ -157,6 +319,20 @@ int quisk_read_sound(void)	// Called from sound thread
 #if DEBUG_IO > 1
 	QuiskPrintTime("  read samples", 0);
 #endif
+	// Perhaps record the samples to a file
+	if (want_record) {
+		if (is_recording_samples) {
+			record_samples(cSamples, nSamples);   // Record samples
+		}
+		else if (file_name_samples[0]) {
+			if (record_samples(NULL, -1))	 // Open file
+				is_recording_samples = 1;
+		}
+	}
+	else if (is_recording_samples) {
+		record_samples(NULL, -2);		 // Close file
+		is_recording_samples = 0;
+	}
 #if ! DEBUG_MIC
 	nSamples = quisk_process_samples(cSamples, nSamples);
 #endif
@@ -167,12 +343,26 @@ int quisk_read_sound(void)	// Called from sound thread
 		quisk_play_alsa(&Playback, nSamples, cSamples, 1);
 	else
 		quisk_play_portaudio(&Playback, nSamples, cSamples, 1);
-	if (rxMode == 7) {
+	if (rxMode == 7 || rxMode == 8 || rxMode == 9) {
 		if (DigitalOutput.portaudio_index < 0)
 			quisk_play_alsa(&DigitalOutput, nSamples, cSamples, 0);
 		else
 			quisk_play_portaudio(&DigitalOutput, nSamples, cSamples, 0);
 	}
+	// Perhaps record the speaker audio to a file
+	if (want_record) {
+		if (is_recording_audio) {
+			record_audio(cSamples, nSamples);   // Record samples
+		}
+		else if (file_name_audio[0]) {
+			if (record_audio(NULL, -1))	 // Open file
+				is_recording_audio = 1;
+		}
+	}
+	else if (is_recording_audio) {
+		record_audio(NULL, -2);		 // Close file
+		is_recording_audio = 0;
+	}
 
 #if DEBUG_IO > 1
 	QuiskPrintTime("  play samples", 0);
@@ -186,7 +376,10 @@ int quisk_read_sound(void)	// Called from sound thread
 		else
 			mic_count = quisk_read_portaudio(&MicCapture, cSamples);
 	}
-	if (rxMode == 7) {		// Discard previous samples and use digital samples
+	if (quisk_record_state == PLAYBACK) {	// Discard previous samples and replace with saved sound
+		quisk_tmp_microphone(cSamples, mic_count);
+	}
+	if (rxMode == 7 || rxMode == 8 || rxMode == 9) {		// Discard previous samples and use digital samples
 		if (DigitalInput.handle) {
 			mic_sample_rate = DigitalInput.sample_rate;
 			if (DigitalInput.portaudio_index < 0)
@@ -347,12 +540,12 @@ void quisk_open_sound(void)	// Called from GUI thread
 	MicCapture.sample_rate = quisk_sound_state.mic_sample_rate;
 	MicCapture.channel_I = quisk_sound_state.mic_channel_I;	// Mic audio is here
 	MicCapture.channel_Q = quisk_sound_state.mic_channel_Q;
-	// Capture device for digital sound for DGTL
+	// Capture device for digital modes
 	strncpy(DigitalInput.name, QuiskGetConfigString ("digital_input_name", ""), QUISK_SC_SIZE);
 	DigitalInput.sample_rate = 48000;
 	DigitalInput.channel_I = 0;
 	DigitalInput.channel_Q = 1;
-	// Playback device for digital sound for DGTL
+	// Playback device for digital modes
 	strncpy(DigitalOutput.name, QuiskGetConfigString ("digital_output_name", ""), QUISK_SC_SIZE);
 	DigitalOutput.sample_rate = quisk_sound_state.playback_rate;	// Radio sound play rate
 	DigitalOutput.channel_I = 0;
@@ -374,10 +567,10 @@ void quisk_open_sound(void)	// Called from GUI thread
 
 	if (pt_sample_read) {		// capture from SDR-IQ by Rf-Space
 		Capture.name[0] = 0;	// zero the capture soundcard name
-    }
+	}
 	else if (quisk_using_udp) {	// samples from UDP at multiple of 48 kHz
 		Capture.name[0] = 0;		// zero the capture soundcard name
-    }
+	}
 	else {		// sound card capture
 		Capture.sample_rate = quisk_sound_state.sample_rate;
 	}
@@ -395,7 +588,7 @@ void quisk_open_sound(void)	// Called from GUI thread
 	MicPlayback.latency_frames = MicPlayback.sample_rate * quisk_sound_state.latency_millisecs / 1000;
 	Capture.latency_frames = 0;
 	MicCapture.latency_frames = 0;
-	// set capture and playback for digital mode DGTL
+	// set capture and playback for digital modes
 	DigitalInput.read_frames = 0;		// Use non-blocking read
 	DigitalInput.latency_frames = 0;
 	DigitalOutput.read_frames = 0;
@@ -494,11 +687,36 @@ PyObject * quisk_sound_errors(PyObject * self, PyObject * args)
 	if (!PyArg_ParseTuple (args, ""))
 		return NULL;
 	pylist = PyList_New(0);
-	AddCard(&Capture,	pylist, "Capture radio samples from ");
-	AddCard(&MicCapture,	pylist, "Capture microphone samples from ");
-	AddCard(&DigitalInput,	pylist, "Capture digital Tx samples from ");
-	AddCard(&Playback,	pylist, "Play radio sound to ");
-	AddCard(&MicPlayback,	pylist, "Play microphone sound to ");
-	AddCard(&DigitalOutput,	pylist, "Play digital mode sound to ");
+	AddCard(&Capture,	pylist, "Capture radio samples");
+	AddCard(&MicCapture,	pylist, "Capture microphone samples");
+	AddCard(&DigitalInput,	pylist, "Capture digital Tx samples");
+	AddCard(&Playback,	pylist, "Play radio sound");
+	AddCard(&MicPlayback,	pylist, "Play microphone sound");
+	AddCard(&DigitalOutput,	pylist, "Play digital mode sound");
 	return pylist;
 }
+
+PyObject * quisk_set_file_record(PyObject * self, PyObject * args)  // called from GUI
+{  /* set the names of the recording files and the recording state */
+	const char * name;
+	int which;
+
+	if (!PyArg_ParseTuple (args, "is", &which, &name))
+		return NULL;
+	switch (which) {
+	case 0:	 // change the name of the audio file
+		strncpy(file_name_audio, name, QUISK_PATH_SIZE);
+		break;
+	case 1:	 // change the name of the sample file
+		strncpy(file_name_samples, name, QUISK_PATH_SIZE);
+		break;
+	case 2:	 // the record button was pressed
+		want_record = 1;
+		break;
+	case 3:	 // the record button was un-pressed
+		want_record = 0;
+		break;
+	}
+	Py_INCREF (Py_None);
+	return Py_None;
+}
